"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QRegion(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qregion.html

    **Detailed Description**

    QRegion is used with **QPainter::setClipRegion** () to limit the paint area
    to what needs to be painted. There is also a **QWidget::repaint** ()
    function that takes a QRegion parameter. QRegion is the best tool for
    minimizing the amount of screen area to be updated by a repaint.

    This class is not suitable for constructing shapes for rendering, especially
    as outlines. Use **QPainterPath**  to create paths and shapes for use with
    **QPainter** .

    QRegion is an **implicitly shared**  class.

    **Creating and Using Regions**

    A region can be created from a rectangle, an ellipse, a polygon or a bitmap.
    Complex regions may be created by combining simple regions using **united**
    (), **intersected** (), **subtracted** (), or **xored** () (exclusive or).
    You can move a region using **translate** ().

    You can test whether a region **isEmpty** () or if it **contains** () a
    **QPoint**  or **QRect** . The bounding rectangle can be found with
    **boundingRect** ().

    Iteration over the region (with **begin** (), **end** (), or C++11 ranged-
    for loops) gives a decomposition of the region into rectangles.

    Example of using complex regions:

    void MyWidget::paintEvent(**QPaintEvent**  *)
        {
            **QRegion**
    r1(**QRect** (100, 100, 200, 80),    // r1: elliptic region
    **QRegion** ::Ellipse);
            **QRegion**  r2(**QRect** (100, 120, 90,
    30));    // r2: rectangular region
            **QRegion**  r3 =
    r1.intersected(r2);        // r3: intersection

            **QPainter**
    painter(this);
            painter.setClipRegion(r3);
            // ...
    // paint clipped graphics
        }

    **See also** **QPainter::setClipRegion** (), **QPainter::setClipRect** (),
    and **QPainterPath** .
    """

    class RegionType(enum.Enum):
        Rectangle: QRegion = ...
        Ellipse: QRegion = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qregion.html#QRegion

        **QRegion::QRegion()**

        Constructs an empty region.

        **See also** **isEmpty** ().
        """
        ...

    @typing.overload
    def __init__(
        self, x: int, y: int, w: int, h: int, type: "QRegion.RegionType" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qregion.html#QRegion-1

        **QRegion::QRegion(int x , int y , int w , int h , QRegion::RegionType t
        = Rectangle)**

        Constructs a rectangular or elliptic region.

        If **t** is `Rectangle`, the region is the filled rectangle ( **x** ,
        **y** , **w** , **h** ). If **t** is `Ellipse`, the region is the filled
        ellipse with center at ( **x** \\+ **w** / 2, **y** \\+ **h** / 2) and
        size ( **w** , **h** ).
        """
        ...

    @typing.overload
    def __init__(self, r: QtCore.QRect, type: "QRegion.RegionType" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qregion.html#QRegion-2

        **QRegion::QRegion(const QRect & r , QRegion::RegionType t =
        Rectangle)**

        This is an overloaded function.

        Create a region based on the rectangle **r** with region type **t**.

        If the rectangle is invalid a null region will be created.

        **See also** **QRegion::RegionType** .
        """
        ...

    @typing.overload
    def __init__(self, a: QPolygon, fillRule: QtCore.Qt.FillRule = ...) -> None:
        """
        https://doc.qt.io/qt-6/qregion.html#QRegion-3

        **QRegion::QRegion(const QPolygon & a , Qt::FillRule fillRule =
        Qt::OddEvenFill)**

        Constructs a polygon region from the point array **a** with the fill
        rule specified by **fillRule**.

        If **fillRule** is **Qt::WindingFill** , the polygon region is defined
        using the winding algorithm; if it is **Qt::OddEvenFill** , the odd-even
        fill algorithm is used.

        **Warning:** This constructor can be used to create complex regions that
        will slow down painting when used.
        """
        ...

    @typing.overload
    def __init__(self, bitmap: QBitmap) -> None:
        """
        https://doc.qt.io/qt-6/qregion.html#QRegion-4

        **QRegion::QRegion(const QRegion & r )**

        Constructs a new region which is equal to region **r**.
        """
        ...

    @typing.overload
    def __init__(self, region: "QRegion") -> None:
        """
        https://doc.qt.io/qt-6/qregion.html#QRegion-5

        **[since 5.7] QRegion::QRegion(QRegion && other )**

        Move-constructs a new region from region **other**. After the call,
        **other** is null.

        This function was introduced in Qt 5.7.

        **See also** **isNull** ().
        """
        ...

    @typing.overload
    def __init__(self, variant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qregion.html#QRegion-6

        **QRegion::QRegion(const QBitmap & bm )**

        Constructs a region from the bitmap **bm**.

        The resulting region consists of the pixels in bitmap **bm** that are
        **Qt::color1** , as if each pixel was a 1 by 1 rectangle.

        This constructor may create complex regions that will slow down painting
        when used. Note that drawing masked pixmaps can be done much faster
        using **QPixmap::setMask** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qregion.html#isNull

        **[since 5.0] bool QRegion::isNull() const**

        Returns `true` if the region is empty; otherwise returns `false`. An
        empty region is a region that contains no points. This function is the
        same as **isEmpty**

        This function was introduced in Qt 5.0.

        **See also** **isEmpty** ().
        """
        ...

    def swap(self, other: "QRegion") -> None:
        """
        https://doc.qt.io/qt-6/qregion.html#swap

        **void QRegion::swap(QRegion & other )**

        Swaps region **other** with this region. This operation is very fast and
        never fails.
        """
        ...

    def rectCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qregion.html#rectCount

        **int QRegion::rectCount() const**

        Returns the number of rectangles that this region is composed of. Same
        as `end() - begin()`.
        """
        ...

    @typing.overload
    def intersects(self, r: "QRegion") -> bool:
        """
        https://doc.qt.io/qt-6/qregion.html#intersects

        **bool QRegion::intersects(const QRegion & region ) const**

        Returns `true` if this region intersects with **region** , otherwise
        returns `false`.
        """
        ...

    @typing.overload
    def intersects(self, r: QtCore.QRect) -> bool:
        """
        https://doc.qt.io/qt-6/qregion.html#intersects-1

        **bool QRegion::intersects(const QRect & rect ) const**

        Returns `true` if this region intersects with **rect** , otherwise
        returns `false`.
        """
        ...

    def xored(self, r: "QRegion") -> "QRegion":
        """
        https://doc.qt.io/qt-6/qregion.html#xored

        **QRegion QRegion::xored(const QRegion & r ) const**

        Returns a region which is the exclusive or (XOR) of this region and
        **r**.

        ![Region XORed](images/rxor.png)

        The figure shows the exclusive or of two elliptical regions.

        **See also** **intersected** (), **united** (), and **subtracted** ().
        """
        ...

    def subtracted(self, r: "QRegion") -> "QRegion":
        """
        https://doc.qt.io/qt-6/qregion.html#subtracted

        **QRegion QRegion::subtracted(const QRegion & r ) const**

        Returns a region which is **r** subtracted from this region.

        ![Region Subtraction](images/rsubtract.png)

        The figure shows the result when the ellipse on the right is subtracted
        from the ellipse on the left (`left - right`).

        **See also** **intersected** (), **united** (), and **xored** ().
        """
        ...

    @typing.overload
    def intersected(self, r: "QRegion") -> "QRegion":
        """
        https://doc.qt.io/qt-6/qregion.html#intersected

        **QRegion QRegion::intersected(const QRegion & r ) const**

        Returns a region which is the intersection of this region and **r**.

        ![Region Intersection](images/rintersect.png)

        The figure shows the intersection of two elliptical regions.

        **See also** **subtracted** (), **united** (), and **xored** ().
        """
        ...

    @typing.overload
    def intersected(self, r: QtCore.QRect) -> "QRegion":
        """
        https://doc.qt.io/qt-6/qregion.html#intersected-1

        **QRegion QRegion::intersected(const QRect & rect ) const**

        Returns a region which is the intersection of this region and the given
        **rect**.

        **See also** **subtracted** (), **united** (), and **xored** ().
        """
        ...

    def setRects(self, a0: typing.Iterable[QtCore.QRect]) -> None:
        """
        https://doc.qt.io/qt-6/qregion.html#setRects

        **void QRegion::setRects(const QRect * rects , int number )**

        Sets the region using the array of rectangles specified by **rects** and
        **number**. The rectangles **must** be optimally Y-X sorted and follow
        these restrictions:

        * The rectangles must not intersect.
          * All rectangles with a given top
        coordinate must have the same height.
          * No two rectangles may abut
        horizontally (they should be combined into a single wider rectangle in
        that case).
          * The rectangles must be sorted in ascending order, with Y
        as the major sort key and X as the minor sort key.
        """
        ...

    def boundingRect(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qregion.html#boundingRect

        **QRect QRegion::boundingRect() const**

        Returns the bounding rectangle of this region. An empty region gives a
        rectangle that is **QRect::isNull** ().
        """
        ...

    @typing.overload
    def united(self, r: "QRegion") -> "QRegion":
        """
        https://doc.qt.io/qt-6/qregion.html#united

        **QRegion QRegion::united(const QRegion & r ) const**

        Returns a region which is the union of this region and **r**.

        ![Region Union](images/runion.png)

        The figure shows the union of two elliptical regions.

        **See also** **intersected** (), **subtracted** (), and **xored** ().
        """
        ...

    @typing.overload
    def united(self, r: QtCore.QRect) -> "QRegion":
        """
        https://doc.qt.io/qt-6/qregion.html#united-1

        **QRegion QRegion::united(const QRect & rect ) const**

        Returns a region which is the union of this region and the given
        **rect**.

        **See also** **intersected** (), **subtracted** (), and **xored** ().
        """
        ...

    @typing.overload
    def translated(self, dx: int, dy: int) -> "QRegion":
        """
        https://doc.qt.io/qt-6/qregion.html#translated

        **QRegion QRegion::translated(int dx , int dy ) const**

        Returns a copy of the region that is translated **dx** along the x axis
        and **dy** along the y axis, relative to the current position. Positive
        values move the region to the right and down.

        **See also** **translate** ().
        """
        ...

    @typing.overload
    def translated(self, p: QtCore.QPoint) -> "QRegion":
        """
        https://doc.qt.io/qt-6/qregion.html#translated-1

        **QRegion QRegion::translated(const QPoint & p ) const**

        This is an overloaded function.

        Returns a copy of the regtion that is translated **p** **.x()** along
        the x axis and **p** **.y()** along the y axis, relative to the current
        position. Positive values move the rectangle to the right and down.

        **See also** **translate** ().
        """
        ...

    @typing.overload
    def translate(self, dx: int, dy: int) -> None:
        """
        https://doc.qt.io/qt-6/qregion.html#translate

        **void QRegion::translate(int dx , int dy )**

        Translates (moves) the region **dx** along the X axis and **dy** along
        the Y axis.
        """
        ...

    @typing.overload
    def translate(self, p: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qregion.html#translate-1

        **void QRegion::translate(const QPoint & point )**

        This is an overloaded function.

        Translates the region **point** **.x()** along the x axis and **point**
        **.y()** along the y axis, relative to the current position. Positive
        values move the region to the right and down.

        Translates to the given **point**.
        """
        ...

    @typing.overload
    def __contains__(self, p: QtCore.QPoint) -> int:
        ...

    @typing.overload
    def __contains__(self, r: QtCore.QRect) -> int:
        ...

    @typing.overload
    def contains(self, p: QtCore.QPoint) -> bool:
        """
        https://doc.qt.io/qt-6/qregion.html#contains

        **bool QRegion::contains(const QPoint & p ) const**

        Returns `true` if the region contains the point **p** ; otherwise
        returns `false`.
        """
        ...

    @typing.overload
    def contains(self, r: QtCore.QRect) -> bool:
        """
        https://doc.qt.io/qt-6/qregion.html#contains-1

        **bool QRegion::contains(const QRect & r ) const**

        This is an overloaded function.

        Returns `true` if the region overlaps the rectangle **r** ; otherwise
        returns `false`.
        """
        ...

    def __bool__(self) -> int:
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qregion.html#isEmpty

        **bool QRegion::isEmpty() const**

        Returns `true` if the region is empty; otherwise returns `false`. An
        empty region is a region that contains no points.

        Example:

        **QRegion**  r1(10, 10, 20, 20);
            r1.isEmpty();               //
        false

            **QRegion**  r3;
            r3.isEmpty();               // true
        **QRegion**  r2(40, 40, 20, 20);
            r3 = r1.intersected(r2);    // r3:
        intersection of r1 and r2
            r3.isEmpty();               // true
        r3 = r1.united(r2);         // r3: union of r1 and r2
            r3.isEmpty();
        // false
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtXml import *


class QDomProcessingInstruction(QDomNode):
    """
    https://doc.qt.io/qt-6/qdomprocessinginstruction.html

    **Detailed Description**

    Processing instructions are used in XML to keep processor-specific
    information in the text of the document.

    The XML declaration that appears at the top of an XML document, typically
    `<?xml version='1.0' encoding='UTF-8'?>`, is treated by QDom as a processing
    instruction. This is unfortunate, since the XML declaration is not a
    processing instruction; among other differences, it cannot be inserted into
    a document anywhere but on the first line.

    Do not use this function to create an xml declaration, since although it has
    the same syntax as a processing instruction, it isn't, and might not be
    treated by QDom as such.

    The content of the processing instruction is retrieved with **data** () and
    set with **setData** (). The processing instruction's target is retrieved
    with **target** ().

    For further information about the Document Object Model see **Level 1**  and
    **Level 2 Core** . For a more general introduction of the DOM implementation
    see the **QDomDocument**  documentation.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomprocessinginstruction.html#QDomProcessingInst
        ruction

        **QDomProcessingInstruction::QDomProcessingInstruction()**

        Constructs an empty processing instruction. Use
        **QDomDocument::createProcessingInstruction** () to create a processing
        instruction with content.
        """
        ...

    @typing.overload
    def __init__(self, x: "QDomProcessingInstruction") -> None:
        """
        https://doc.qt.io/qt-6/qdomprocessinginstruction.html#QDomProcessingInst
        ruction-1

        **QDomProcessingInstruction::QDomProcessingInstruction(const
        QDomProcessingInstruction & x )**

        Constructs a copy of **x**.

        The data of the copy is shared (shallow copy): modifying one node will
        also change the other. If you want to make a deep copy, use
        **cloneNode** ().
        """
        ...

    def nodeType(self) -> QDomNode.NodeType:
        """
        https://doc.qt.io/qt-6/qdomprocessinginstruction.html#nodeType

        **QDomNode::NodeType QDomProcessingInstruction::nodeType() const**

        Returns `ProcessingInstructionNode`.
        """
        ...

    def setData(self, d: str) -> None:
        """
        https://doc.qt.io/qt-6/qdomprocessinginstruction.html#setData

        **void QDomProcessingInstruction::setData(const QString & d )**

        Sets the data contained in the processing instruction to **d**.

        **See also** **data** ().
        """
        ...

    def data(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomprocessinginstruction.html#data

        **QString QDomProcessingInstruction::data() const**

        Returns the content of this processing instruction.

        **See also** **setData** () and **target** ().
        """
        ...

    def target(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomprocessinginstruction.html#target

        **QString QDomProcessingInstruction::target() const**

        Returns the target of this processing instruction.

        **See also** **data** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtXml import *


class QDomDocumentFragment(QDomNode):
    """
    https://doc.qt.io/qt-6/qdomdocumentfragment.html

    **Detailed Description**

    If you want to do complex tree operations it is useful to have a lightweight
    class to store nodes and their relations. QDomDocumentFragment stores a
    subtree of a document which does not necessarily represent a well-formed XML
    document.

    QDomDocumentFragment is also useful if you want to group several nodes in a
    list and insert them all together as children of some node. In these cases
    QDomDocumentFragment can be used as a temporary container for this list of
    children.

    The most important feature of QDomDocumentFragment is that it is treated in
    a special way by **QDomNode::insertAfter** (), **QDomNode::insertBefore**
    (), **QDomNode::replaceChild** () and **QDomNode::appendChild** (): instead
    of inserting the fragment itself, all the fragment's children are inserted.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomdocumentfragment.html#QDomDocumentFragment

        **QDomDocumentFragment::QDomDocumentFragment()**

        Constructs an empty document fragment.
        """
        ...

    @typing.overload
    def __init__(self, x: "QDomDocumentFragment") -> None:
        """
        https://doc.qt.io/qt-6/qdomdocumentfragment.html#QDomDocumentFragment-1

        **QDomDocumentFragment::QDomDocumentFragment(const QDomDocumentFragment
        & x )**

        Constructs a copy of **x**.

        The data of the copy is shared (shallow copy): modifying one node will
        also change the other. If you want to make a deep copy, use
        **cloneNode** ().
        """
        ...

    def nodeType(self) -> QDomNode.NodeType:
        """
        https://doc.qt.io/qt-6/qdomdocumentfragment.html#nodeType

        **QDomNode::NodeType QDomDocumentFragment::nodeType() const**

        Returns `DocumentFragment`.

        **See also** **isDocumentFragment** () and
        **QDomNode::toDocumentFragment** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QFileSelector(QObject):
    """
    https://doc.qt.io/qt-6/qfileselector.html

    **Detailed Description**

    QFileSelector is a convenience for selecting file variants based on platform
    or device characteristics. This allows you to develop and deploy one
    codebase containing all the different variants more easily in some
    circumstances, such as when the correct variant cannot be determined during
    the deploy step.

    **Using QFileSelector**

    If you always use the same file you do not need to use QFileSelector.

    Consider the following example usage, where you want to use different
    settings files on different locales. You might select code between locales
    like this:

    **QString**  defaultsBasePath = "data/";
            **QString**  defaultsPath =
    defaultsBasePath + "defaults.conf";
            **QString**  localizedPath =
    defaultsBasePath
                    + **QString**
    ("%1/defaults.conf").arg(**QLocale** ().name());
            if (**QFile**
    ::exists(localizedPath))
                defaultsPath = localizedPath;
    **QFile**  defaults(defaultsPath);

    Similarly, if you want to pick a different data file based on target
    platform, your code might look something like this:

    **QString**  defaultsPath = "data/defaults.conf";
        #if
    defined(Q_OS_ANDROID)
            defaultsPath = "data/android/defaults.conf";
    #elif defined(Q_OS_IOS)
            defaultsPath = "data/ios/defaults.conf";
    #endif
            **QFile**  defaults(defaultsPath);

    QFileSelector provides a convenient alternative to writing such boilerplate
    code, and in the latter case it allows you to start using an platform-
    specific configuration without a recompile. QFileSelector also allows for
    chaining of multiple selectors in a convenient way, for example selecting a
    different file only on certain combinations of platform and locale. For
    example, to select based on platform and/or locale, the code is as follows:

    **QFileSelector**  selector;
            **QFile**
    defaultsFile(selector.select("data/defaults.conf"));

    The files to be selected are placed in directories named with a `'+'` and a
    selector name. In the above example you could have the platform
    configurations selected by placing them in the following locations:

    data/defaults.conf
            data/+android/defaults.conf
    data/+ios/+en_GB/defaults.conf

    To find selected files, QFileSelector looks in the same directory as the
    base file. If there are any directories of the form +<selector> with an
    active selector, QFileSelector will prefer a file with the same file name
    from that directory over the base file. These directories can be nested to
    check against multiple selectors, for example:

    images/background.png
            images/+android/+en_GB/background.png

    With those files available, you would select a different file on the android
    platform, but only if the locale was en_GB.

    For error handling in the case no valid selectors are present, it is
    recommended to have a default or error-handling file in the base file
    location even if you expect selectors to be present for all deployments.

    In a future version, some may be marked as deploy-time static and be moved
    during the deployment step as an optimization. As selectors come with a
    performance cost, it is recommended to avoid their use in circumstances
    involving performance-critical code.

    **Adding Selectors**

    Selectors normally available are

    * platform, any of the following strings which match the platform the
    application is running on (list not exhaustive): android, ios, osx, darwin,
    mac, macos, linux, qnx, unix, windows. On Linux, if it can be determined,
    the name of the distribution too, like debian, fedora or opensuse.
      *
    locale, same as QLocale().name().

    Further selectors will be added from the `QT_FILE_SELECTORS` environment
    variable, which when set should be a set of comma separated selectors. Note
    that this variable will only be read once; selectors may not update if the
    variable changes while the application is running. The initial set of
    selectors are evaluated only once, on first use.

    You can also add extra selectors at runtime for custom behavior. These will
    be used in any future calls to **select** (). If the extra selectors list
    has been changed, calls to **select** () will use the new list and may
    return differently.

    **Conflict Resolution when Multiple Selectors Apply**

    When multiple selectors could be applied to the same file, the first
    matching selector is chosen. The order selectors are checked in are:

    1. Selectors set via **setExtraSelectors** (), in the order they are in the
    list
      2. Selectors in the `QT_FILE_SELECTORS` environment variable, from
    left to right
      3. Locale
      4. Platform

    Here is an example involving multiple selectors matching at the same time.
    It uses platform selectors, plus an extra selector named "admin" is set by
    the application based on user credentials. The example is sorted so that the
    lowest matching file would be chosen if all selectors were present:

    images/background.png
            images/+linux/background.png
    images/+windows/background.png
            images/+admin/background.png
    images/+admin/+linux/background.png

    Because extra selectors are checked before platform the
    `+admin/background.png` will be chosen on Windows when the admin selector is
    set, and `+windows/background.png` will be chosen on Windows when the admin
    selector is not set. On Linux, the `+admin/+linux/background.png` will be
    chosen when admin is set, and the `+linux/background.png` when it is not.
    """

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qfileselector.html#QFileSelector

        **QFileSelector::QFileSelector(QObject * parent = nullptr)**

        Create a QFileSelector instance. This instance will have the same static
        selectors as other QFileSelector instances, but its own set of extra
        selectors.

        If supplied, it will have the given **QObject**  **parent**.
        """
        ...

    def allSelectors(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfileselector.html#allSelectors

        **QStringList QFileSelector::allSelectors() const**

        Returns the complete, ordered list of selectors used by this instance
        """
        ...

    def setExtraSelectors(self, list: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qfileselector.html#setExtraSelectors

        **void QFileSelector::setExtraSelectors(const QStringList & list )**

        Sets the **list** of extra selectors which have been added
        programmatically to this instance.

        These selectors have priority over any which have been automatically
        picked up.

        **See also** **extraSelectors** ().
        """
        ...

    def extraSelectors(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfileselector.html#extraSelectors

        **QStringList QFileSelector::extraSelectors() const**

        Returns the list of extra selectors which have been added
        programmatically to this instance.

        **See also** **setExtraSelectors** ().
        """
        ...

    @typing.overload
    def select(self, filePath: str) -> str:
        """
        https://doc.qt.io/qt-6/qfileselector.html#select

        **QString QFileSelector::select(const QString & filePath ) const**

        This function returns the selected version of the path, based on the
        conditions at runtime. If no selectable files are present, returns the
        original **filePath**.

        If the original file does not exist, the original **filePath** is
        returned. This means that you must have a base file to fall back on, you
        cannot have only files in selectable sub-directories.

        See the class overview for the selection algorithm.
        """
        ...

    @typing.overload
    def select(self, filePath: "QUrl") -> "QUrl":
        """
        https://doc.qt.io/qt-6/qfileselector.html#select-1

        **QUrl QFileSelector::select(const QUrl & filePath ) const**

        This is a convenience version of select operating on **QUrl**  objects.
        If the scheme is not file or qrc, **filePath** is returned immediately.
        Otherwise selection is applied to the path of **filePath** and a
        **QUrl**  is returned with the selected path and other **QUrl**  parts
        the same as **filePath**.

        See the class overview for the selection algorithm.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QMovie(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qmovie.html

    **Detailed Description**

    This class is used to show simple animations without sound.

    First, create a QMovie object by passing either the name of a file or a
    pointer to a **QIODevice**  containing an animated image format to QMovie's
    constructor. You can call **isValid** () to check if the image data is
    valid, before starting the movie. To start the movie, call **start** ().
    QMovie will enter **Running**  state, and emit **started** () and
    **stateChanged** (). To get the current state of the movie, call **state**
    ().

    To display the movie in your application, you can pass your QMovie object to
    **QLabel::setMovie** (). Example:

    **QLabel**  label;
        **QMovie**  *movie = new **QMovie**
    ("animations/fire.gif");

        label.setMovie(movie);
        movie->start();

    Whenever a new frame is available in the movie, QMovie will emit **updated**
    (). If the size of the frame changes, **resized** () is emitted. You can
    call **currentImage** () or **currentPixmap** () to get a copy of the
    current frame. When the movie is done, QMovie emits **finished** (). If any
    error occurs during playback (i.e, the image file is corrupt), QMovie will
    emit **error** ().

    You can control the speed of the movie playback by calling **setSpeed** (),
    which takes the percentage of the original speed as an argument. Pause the
    movie by calling **setPaused** (true). QMovie will then enter **Paused**
    state and emit **stateChanged** (). If you call **setPaused** (false),
    QMovie will reenter **Running**  state and start the movie again. To stop
    the movie, call **stop** ().

    Certain animation formats allow you to set the background color. You can
    call **setBackgroundColor** () to set the color, or **backgroundColor** ()
    to retrieve the current background color.

    **currentFrameNumber** () returns the sequence number of the current frame.
    The first frame in the animation has the sequence number 0. **frameCount**
    () returns the total number of frames in the animation, if the image format
    supports this. You can call **loopCount** () to get the number of times the
    movie should loop before finishing. **nextFrameDelay** () returns the number
    of milliseconds the current frame should be displayed.

    QMovie can be instructed to cache frames of an animation by calling
    **setCacheMode** ().

    Call **supportedFormats** () for a list of formats that QMovie supports.

    **See also** **QLabel** , **QImageReader** , and **Movie Example** .
    """

    class CacheMode(enum.Enum):
        CacheNone: QMovie = ...
        CacheAll: QMovie = ...

    class MovieState(enum.Enum):
        NotRunning: QMovie = ...
        Paused: QMovie = ...
        Running: QMovie = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qmovie.html#QMovie

        **QMovie::QMovie(QObject * parent = nullptr)**

        Constructs a QMovie object, passing the **parent** object to **QObject**
        's constructor.

        **See also** **setFileName** (), **setDevice** (), and **setFormat** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        device: QtCore.QIODevice,
        format: QtCore.QByteArray = ...,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmovie.html#QMovie-1

        **QMovie::QMovie(QIODevice * device , const QByteArray & format =
        QByteArray(), QObject * parent = nullptr)**

        Constructs a QMovie object. QMovie will use read image data from
        **device** , which it assumes is open and readable. If **format** is not
        empty, QMovie will use the image format **format** for decoding the
        image data. Otherwise, QMovie will attempt to guess the format.

        The **parent** object is passed to **QObject** 's constructor.
        """
        ...

    @typing.overload
    def __init__(
        self,
        fileName: str,
        format: QtCore.QByteArray = ...,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmovie.html#QMovie-2

        **QMovie::QMovie(const QString & fileName , const QByteArray & format =
        QByteArray(), QObject * parent = nullptr)**

        Constructs a QMovie object. QMovie will use read image data from
        **fileName**. If **format** is not empty, QMovie will use the image
        format **format** for decoding the image data. Otherwise, QMovie will
        attempt to guess the format.

        The **parent** object is passed to **QObject** 's constructor.
        """
        ...

    def lastErrorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qmovie.html#lastErrorString

        **QString QMovie::lastErrorString() const**

        Returns a human-readable representation of the most recent error that
        occurred while attempting to read image data.

        **See also** **lastError** ().
        """
        ...

    def lastError(self) -> QImageReader.ImageReaderError:
        """
        https://doc.qt.io/qt-6/qmovie.html#lastError

        **QImageReader::ImageReaderError QMovie::lastError() const**

        Returns the most recent error that occurred while attempting to read
        image data.

        **See also** **lastErrorString** ().
        """
        ...

    def stop(self) -> None:
        """
        https://doc.qt.io/qt-6/qmovie.html#stop

        **[slot] void QMovie::stop()**

        Stops the movie. **QMovie**  enters **NotRunning**  state, and stops
        emitting **updated** () and **resized** (). If **start** () is called
        again, the movie will restart from the beginning.

        If **QMovie**  is already in the **NotRunning**  state, this function
        does nothing.

        **See also** **start** () and **setPaused** ().
        """
        ...

    def setPaused(self, paused: bool) -> None:
        """
        https://doc.qt.io/qt-6/qmovie.html#setPaused

        **[slot] void QMovie::setPaused(bool paused )**

        If **paused** is true, **QMovie**  will enter **Paused**  state and emit
        **stateChanged** (Paused); otherwise it will enter **Running**  state
        and emit **stateChanged** (Running).

        **See also** **state** ().
        """
        ...

    def jumpToNextFrame(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmovie.html#jumpToNextFrame

        **[slot] bool QMovie::jumpToNextFrame()**

        Jumps to the next frame. Returns `true` on success; otherwise returns
        `false`.
        """
        ...

    def start(self) -> None:
        """
        https://doc.qt.io/qt-6/qmovie.html#start

        **[slot] void QMovie::start()**

        Starts the movie. **QMovie**  will enter **Running**  state, and start
        emitting **updated** () and **resized** () as the movie progresses.

        If **QMovie**  is in the **Paused**  state, this function is equivalent
        to calling **setPaused** (false). If **QMovie**  is already in the
        **Running**  state, this function does nothing.

        **See also** **stop** () and **setPaused** ().
        """
        ...

    def setCacheMode(self, mode: "QMovie.CacheMode") -> None:
        """
        https://doc.qt.io/qt-6/qmovie.html#cacheMode-prop

        **[bindable] cacheMode : CacheMode**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the movie's cache mode

        Caching frames can be useful when the underlying animation format
        handler that **QMovie**  relies on to decode the animation data does not
        support jumping to particular frames in the animation, or even
        "rewinding" the animation to the beginning (for looping). Furthermore,
        if the image data comes from a sequential device, it is not possible for
        the underlying animation handler to seek back to frames whose data has
        already been read (making looping altogether impossible).

        To aid in such situations, a **QMovie**  object can be instructed to
        cache the frames, at the added memory cost of keeping the frames in
        memory for the lifetime of the object.

        By default, this property is set to **CacheNone** .

        **See also** **QMovie::CacheMode** .
        """
        ...

    def cacheMode(self) -> "QMovie.CacheMode":
        """
        https://doc.qt.io/qt-6/qmovie.html#cacheMode-prop

        **[bindable] cacheMode : CacheMode**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the movie's cache mode

        Caching frames can be useful when the underlying animation format
        handler that **QMovie**  relies on to decode the animation data does not
        support jumping to particular frames in the animation, or even
        "rewinding" the animation to the beginning (for looping). Furthermore,
        if the image data comes from a sequential device, it is not possible for
        the underlying animation handler to seek back to frames whose data has
        already been read (making looping altogether impossible).

        To aid in such situations, a **QMovie**  object can be instructed to
        cache the frames, at the added memory cost of keeping the frames in
        memory for the lifetime of the object.

        By default, this property is set to **CacheNone** .

        **See also** **QMovie::CacheMode** .
        """
        ...

    def setScaledSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qmovie.html#setScaledSize

        **void QMovie::setScaledSize(const QSize & size )**

        Sets the scaled frame size to **size**.

        **See also** **scaledSize** () and **QImageReader::setScaledSize** ().
        """
        ...

    def scaledSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qmovie.html#scaledSize

        **QSize QMovie::scaledSize()**

        Returns the scaled size of frames.

        **See also** **setScaledSize** () and **QImageReader::scaledSize** ().
        """
        ...

    def speed(self) -> int:
        """
        https://doc.qt.io/qt-6/qmovie.html#speed-prop

        **[bindable] speed : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the movie's speed

        The speed is measured in percentage of the original movie speed. The
        default speed is 100%. Example:

        **QMovie**  movie("racecar.gif");
            movie.setSpeed(200); // 2x speed

        **Member Function Documentation**
        """
        ...

    def setSpeed(self, percentSpeed: int) -> None:
        """
        https://doc.qt.io/qt-6/qmovie.html#speed-prop

        **[bindable] speed : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the movie's speed

        The speed is measured in percentage of the original movie speed. The
        default speed is 100%. Example:

        **QMovie**  movie("racecar.gif");
            movie.setSpeed(200); // 2x speed

        **Member Function Documentation**
        """
        ...

    def currentFrameNumber(self) -> int:
        """
        https://doc.qt.io/qt-6/qmovie.html#currentFrameNumber

        **int QMovie::currentFrameNumber() const**

        Returns the sequence number of the current frame. The number of the
        first frame in the movie is 0.
        """
        ...

    def nextFrameDelay(self) -> int:
        """
        https://doc.qt.io/qt-6/qmovie.html#nextFrameDelay

        **int QMovie::nextFrameDelay() const**

        Returns the number of milliseconds **QMovie**  will wait before updating
        the next frame in the animation.
        """
        ...

    def frameCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qmovie.html#frameCount

        **int QMovie::frameCount() const**

        Returns the number of frames in the movie.

        Certain animation formats do not support this feature, in which case 0
        is returned.
        """
        ...

    def loopCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qmovie.html#loopCount

        **int QMovie::loopCount() const**

        Returns the number of times the movie will loop before it finishes. If
        the movie will only play once (no looping), loopCount returns 0. If the
        movie loops forever, loopCount returns -1.

        Note that, if the image data comes from a sequential device (e.g. a
        socket), **QMovie**  can only loop the movie if the **cacheMode**  is
        set to **QMovie::CacheAll** .
        """
        ...

    def jumpToFrame(self, frameNumber: int) -> bool:
        """
        https://doc.qt.io/qt-6/qmovie.html#jumpToFrame

        **bool QMovie::jumpToFrame(int frameNumber )**

        Jumps to frame number **frameNumber**. Returns `true` on success;
        otherwise returns `false`.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmovie.html#isValid

        **bool QMovie::isValid() const**

        Returns `true` if the movie is valid (e.g., the image data is readable
        and the image format is supported); otherwise returns `false`.

        For information about why the movie is not valid, see **lastError** ().
        """
        ...

    def currentPixmap(self) -> QPixmap:
        """
        https://doc.qt.io/qt-6/qmovie.html#currentPixmap

        **QPixmap QMovie::currentPixmap() const**

        Returns the current frame as a **QPixmap** .

        **See also** **currentImage** () and **updated** ().
        """
        ...

    def currentImage(self) -> QImage:
        """
        https://doc.qt.io/qt-6/qmovie.html#currentImage

        **QImage QMovie::currentImage() const**

        Returns the current frame as a **QImage** .

        **See also** **currentPixmap** () and **updated** ().
        """
        ...

    def frameRect(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qmovie.html#frameRect

        **QRect QMovie::frameRect() const**

        Returns the rect of the last frame. If no frame has yet been updated, an
        invalid **QRect**  is returned.

        **See also** **currentImage** () and **currentPixmap** ().
        """
        ...

    def state(self) -> "QMovie.MovieState":
        """
        https://doc.qt.io/qt-6/qmovie.html#state

        **QMovie::MovieState QMovie::state() const**

        Returns the current state of **QMovie** .

        **See also** **MovieState**  and **stateChanged** ().
        """
        ...

    def backgroundColor(self) -> QColor:
        """
        https://doc.qt.io/qt-6/qmovie.html#backgroundColor

        **QColor QMovie::backgroundColor() const**

        Returns the background color of the movie. If no background color has
        been assigned, an invalid **QColor**  is returned.

        **See also** **setBackgroundColor** ().
        """
        ...

    def setBackgroundColor(
        self, color: typing.Union[QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmovie.html#setBackgroundColor

        **void QMovie::setBackgroundColor(const QColor & color )**

        For image formats that support it, this function sets the background
        color to **color**.

        **See also** **backgroundColor** ().
        """
        ...

    def format(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qmovie.html#format

        **QByteArray QMovie::format() const**

        Returns the format that **QMovie**  uses when decoding image data. If no
        format has been assigned, an empty QByteArray() is returned.

        **See also** **setFormat** ().
        """
        ...

    def setFormat(self, format: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qmovie.html#setFormat

        **void QMovie::setFormat(const QByteArray & format )**

        Sets the format that **QMovie**  will use when decoding image data, to
        **format**. By default, **QMovie**  will attempt to guess the format of
        the image data.

        You can call **supportedFormats** () for the full list of formats
        **QMovie**  supports.

        **See also** **format** () and **QImageReader::supportedImageFormats**
        ().
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qmovie.html#fileName

        **QString QMovie::fileName() const**

        Returns the name of the file that **QMovie**  reads image data from. If
        no file name has been assigned, or if the assigned device is not a file,
        an empty **QString**  is returned.

        **See also** **setFileName** () and **device** ().
        """
        ...

    def setFileName(self, fileName: str) -> None:
        """
        https://doc.qt.io/qt-6/qmovie.html#setFileName

        **void QMovie::setFileName(const QString & fileName )**

        Sets the name of the file that **QMovie**  reads image data from, to
        **fileName**.

        **See also** **fileName** (), **setDevice** (), and **setFormat** ().
        """
        ...

    def device(self) -> QtCore.QIODevice:
        """
        https://doc.qt.io/qt-6/qmovie.html#device

        **QIODevice *QMovie::device() const**

        Returns the device **QMovie**  reads image data from. If no device has
        currently been assigned, `nullptr` is returned.

        **See also** **setDevice** () and **fileName** ().
        """
        ...

    def setDevice(self, device: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qmovie.html#setDevice

        **void QMovie::setDevice(QIODevice * device )**

        Sets the current device to **device**. **QMovie**  will read image data
        from this device when the movie is running.

        **See also** **device** () and **setFormat** ().
        """
        ...

    @staticmethod
    def supportedFormats() -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qmovie.html#supportedFormats

        **[static] QList<QByteArray> QMovie::supportedFormats()**

        Returns the list of image formats supported by **QMovie** .

        **See also** **QImageReader::supportedImageFormats** ().
        """
        ...

    @property
    def error(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmovie.html#error

        **[signal] void QMovie::error(QImageReader::ImageReaderError error )**

        This signal is emitted by **QMovie**  when the error **error** occurred
        during playback. **QMovie**  will stop the movie, and enter
        **QMovie::NotRunning**  state.

        **See also** **lastError** () and **lastErrorString** ().
        """
        ...

    @property
    def finished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmovie.html#finished

        **[signal] void QMovie::finished()**

        This signal is emitted when the movie has finished.

        **See also** **QMovie::stop** ().
        """
        ...

    @property
    def frameChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmovie.html#frameChanged

        **[signal] void QMovie::frameChanged(int frameNumber )**

        This signal is emitted when the frame number has changed to
        **frameNumber**. You can call **currentImage** () or **currentPixmap**
        () to get a copy of the frame.
        """
        ...

    @property
    def resized(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmovie.html#resized

        **[signal] void QMovie::resized(const QSize & size )**

        This signal is emitted when the current frame has been resized to
        **size**. This effect is sometimes used in animations as an alternative
        to replacing the frame. You can call **currentImage** () or
        **currentPixmap** () to get a copy of the updated frame.
        """
        ...

    @property
    def started(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmovie.html#started

        **[signal] void QMovie::started()**

        This signal is emitted after **QMovie::start** () has been called, and
        **QMovie**  has entered **QMovie::Running**  state.
        """
        ...

    @property
    def stateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmovie.html#stateChanged

        **[signal] void QMovie::stateChanged(QMovie::MovieState state )**

        This signal is emitted every time the state of the movie changes. The
        new state is specified by **state**.

        **See also** **QMovie::state** ().
        """
        ...

    @property
    def updated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmovie.html#updated

        **[signal] void QMovie::updated(const QRect & rect )**

        This signal is emitted when the rect **rect** in the current frame has
        been updated. You can call **currentImage** () or **currentPixmap** ()
        to get a copy of the updated frame.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtWidgets
from PyQt6 import QtCore
from PyQt6.QtDesigner import *


class QDesignerObjectInspectorInterface(QtWidgets.QWidget):
    """
    https://doc.qt.io/qt-6/qdesignerobjectinspectorinterface.html

    **Detailed Description**

    You can use the QDesignerObjectInspectorInterface to change the current form
    window selection. For example, when implementing a custom widget plugin:

    **QDesignerObjectInspectorInterface**  *objectInspector = 0;
    objectInspector = formEditor->objectInspector();
    **QDesignerFormWindowManagerInterface**  *manager = 0;
                manager =
    formEditor->formWindowManager();
    objectInspector->setFormWindow(manager->formWindow(0));

    The QDesignerObjectInspectorInterface class is not intended to be
    instantiated directly. You can retrieve an interface to **Qt Designer** 's
    object inspector using the **QDesignerFormEditorInterface::objectInspector**
    () function. A pointer to **Qt Designer** 's current
    **QDesignerFormEditorInterface**  object (`formEditor` in the example above)
    is provided by the **QDesignerCustomWidgetInterface::initialize** ()
    function's parameter. When implementing a custom widget plugin, you must
    subclass the **QDesignerCustomWidgetInterface**  to expose your plugin to
    **Qt Designer**.

    The interface provides the **core** () function that you can use to retrieve
    a pointer to **Qt Designer** 's current **QDesignerFormEditorInterface**
    object, and the **setFormWindow** () function that enables you to change the
    current form window selection.

    **See also** **QDesignerFormEditorInterface**  and
    **QDesignerFormWindowInterface** .
    """

    def __init__(
        self, parent: QtWidgets.QWidget, flags: QtCore.Qt.WindowType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerobjectinspectorinterface.html#QDesignerO
        bjectInspectorInterface

        **QDesignerObjectInspectorInterface::QDesignerObjectInspectorInterface(Q
        Widget * parent , Qt::WindowFlags flags = {})**

        Constructs an object inspector interface with the given **parent** and
        the specified window **flags**.
        """
        ...

    def setFormWindow(self, formWindow: QDesignerFormWindowInterface) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerobjectinspectorinterface.html#setFormWin
        dow

        **[pure virtual slot] void QDesignerObjectInspectorInterface::setFormWin
        dow(QDesignerFormWindowInterface * formWindow )**

        Sets the currently selected form window to **formWindow**.
        """
        ...

    def core(self) -> QDesignerFormEditorInterface:
        """
        https://doc.qt.io/qt-6/qdesignerobjectinspectorinterface.html#core

        **[virtual] QDesignerFormEditorInterface
        *QDesignerObjectInspectorInterface::core() const**

        Returns a pointer to **Qt Designer** 's current
        **QDesignerFormEditorInterface**  object.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtOpenGL import *
import enum


class QOpenGLBuffer(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qopenglbuffer.html

    **Detailed Description**

    Buffer objects are created in the OpenGL server so that the client
    application can avoid uploading vertices, indices, texture image data, etc
    every time they are needed.

    QOpenGLBuffer objects can be copied around as a reference to the underlying
    OpenGL buffer object:

    **QOpenGLBuffer**  buffer1(**QOpenGLBuffer** ::IndexBuffer);
    buffer1.create();

        **QOpenGLBuffer**  buffer2 = buffer1;

    QOpenGLBuffer performs a shallow copy when objects are copied in this
    manner, but does not implement copy-on-write semantics. The original object
    will be affected whenever the copy is modified.
    """

    class RangeAccessFlag(enum.Flag):
        RangeRead: QOpenGLBuffer = ...
        RangeWrite: QOpenGLBuffer = ...
        RangeInvalidate: QOpenGLBuffer = ...
        RangeInvalidateBuffer: QOpenGLBuffer = ...
        RangeFlushExplicit: QOpenGLBuffer = ...
        RangeUnsynchronized: QOpenGLBuffer = ...

    class Access(enum.Enum):
        ReadOnly: QOpenGLBuffer = ...
        WriteOnly: QOpenGLBuffer = ...
        ReadWrite: QOpenGLBuffer = ...

    class UsagePattern(enum.Enum):
        StreamDraw: QOpenGLBuffer = ...
        StreamRead: QOpenGLBuffer = ...
        StreamCopy: QOpenGLBuffer = ...
        StaticDraw: QOpenGLBuffer = ...
        StaticRead: QOpenGLBuffer = ...
        StaticCopy: QOpenGLBuffer = ...
        DynamicDraw: QOpenGLBuffer = ...
        DynamicRead: QOpenGLBuffer = ...
        DynamicCopy: QOpenGLBuffer = ...

    class Type(enum.Enum):
        VertexBuffer: QOpenGLBuffer = ...
        IndexBuffer: QOpenGLBuffer = ...
        PixelPackBuffer: QOpenGLBuffer = ...
        PixelUnpackBuffer: QOpenGLBuffer = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#QOpenGLBuffer

        **QOpenGLBuffer::QOpenGLBuffer()**

        Constructs a new buffer object of type **QOpenGLBuffer::VertexBuffer** .

        Note: this constructor just creates the QOpenGLBuffer instance. The
        actual buffer object in the OpenGL server is not created until
        **create** () is called.

        **See also** **create** ().
        """
        ...

    @typing.overload
    def __init__(self, type: "QOpenGLBuffer.Type") -> None:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#QOpenGLBuffer-1

        **QOpenGLBuffer::QOpenGLBuffer(QOpenGLBuffer::Type type )**

        Constructs a new buffer object of **type**.

        Note: this constructor just creates the QOpenGLBuffer instance. The
        actual buffer object in the OpenGL server is not created until
        **create** () is called.

        **See also** **create** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QOpenGLBuffer") -> None:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#QOpenGLBuffer-2

        **QOpenGLBuffer::QOpenGLBuffer(const QOpenGLBuffer & other )**

        Constructs a shallow copy of **other**.

        Note: QOpenGLBuffer does not implement copy-on-write semantics, so
        **other** will be affected whenever the copy is modified.
        """
        ...

    def mapRange(
        self, offset: int, count: int, access: "QOpenGLBuffer.RangeAccessFlag"
    ) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#mapRange

        **void *QOpenGLBuffer::mapRange(int offset , int count ,
        QOpenGLBuffer::RangeAccessFlags access )**

        Maps the range specified by **offset** and **count** of the contents of
        this buffer into the application's memory space and returns a pointer to
        it. Returns null if memory mapping is not possible. The **access**
        parameter specifies a combination of access flags.

        It is assumed that **create** () has been called on this buffer and that
        it has been bound to the current context.

        **Note:** This function is not available on OpenGL ES 2.0 and earlier.

        **See also** **unmap** (), **create** (), and **bind** ().
        """
        ...

    def unmap(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#unmap

        **bool QOpenGLBuffer::unmap()**

        Unmaps the buffer after it was mapped into the application's memory
        space with a previous call to **map** (). Returns `true` if the unmap
        succeeded; false otherwise.

        It is assumed that this buffer has been bound to the current context,
        and that it was previously mapped with **map** ().

        **Note:** This function is only supported under OpenGL ES 2.0 and
        earlier if the `GL_OES_mapbuffer` extension is present.

        **See also** **map** ().
        """
        ...

    def map(self, access: "QOpenGLBuffer.Access") -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#map

        **void *QOpenGLBuffer::map(QOpenGLBuffer::Access access )**

        Maps the contents of this buffer into the application's memory space and
        returns a pointer to it. Returns null if memory mapping is not possible.
        The **access** parameter indicates the type of access to be performed.

        It is assumed that **create** () has been called on this buffer and that
        it has been bound to the current context.

        **Note:** This function is only supported under OpenGL ES 2.0 or earlier
        if the `GL_OES_mapbuffer` extension is present.

        **Note:** On OpenGL ES 3.0 and newer, or, in case if desktop OpenGL, if
        `GL_ARB_map_buffer_range` is supported, this function uses
        `glMapBufferRange` instead of `glMapBuffer`.

        **See also** **unmap** (), **create** (), **bind** (), and **mapRange**
        ().
        """
        ...

    @typing.overload
    def allocate(self, data: PyQt6.sip.voidptr, count: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#allocate

        **void QOpenGLBuffer::allocate(const void * data , int count )**

        Allocates **count** bytes of space to the buffer, initialized to the
        contents of **data**. Any previous contents will be removed.

        It is assumed that **create** () has been called on this buffer and that
        it has been bound to the current context.

        **See also** **create** (), **read** (), and **write** ().
        """
        ...

    @typing.overload
    def allocate(self, count: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#allocate-1

        **void QOpenGLBuffer::allocate(int count )**

        This is an overloaded function.

        Allocates **count** bytes of space to the buffer. Any previous contents
        will be removed.

        It is assumed that **create** () has been called on this buffer and that
        it has been bound to the current context.

        **See also** **create** () and **write** ().
        """
        ...

    def write(self, offset: int, data: PyQt6.sip.voidptr, count: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#write

        **void QOpenGLBuffer::write(int offset , const void * data , int count
        )**

        Replaces the **count** bytes of this buffer starting at **offset** with
        the contents of **data**. Any other bytes in the buffer will be left
        unmodified.

        It is assumed that **create** () has been called on this buffer and that
        it has been bound to the current context.

        **See also** **create** (), **read** (), and **allocate** ().
        """
        ...

    def read(self, offset: int, data: PyQt6.sip.voidptr, count: int) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#read

        **bool QOpenGLBuffer::read(int offset , void * data , int count )**

        Reads the **count** bytes in this buffer starting at **offset** into
        **data**. Returns `true` on success; false if reading from the buffer is
        not supported. Buffer reading is not supported under OpenGL/ES.

        It is assumed that this buffer has been bound to the current context.

        **See also** **write** () and **bind** ().
        """
        ...

    def __len__(self) -> int:
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#size

        **int QOpenGLBuffer::size() const**

        Returns the size of the data in this buffer, for reading operations.
        Returns -1 if fetching the buffer size is not supported, or the buffer
        has not been created.

        It is assumed that this buffer has been bound to the current context.

        **See also** **isCreated** () and **bind** ().
        """
        ...

    def bufferId(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#bufferId

        **GLuint QOpenGLBuffer::bufferId() const**

        Returns the OpenGL identifier associated with this buffer; zero if the
        buffer has not been created.

        **See also** **isCreated** ().
        """
        ...

    @typing.overload
    def release(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#release

        **void QOpenGLBuffer::release()**

        Releases the buffer associated with this object from the current OpenGL
        context.

        This function must be called with the same **QOpenGLContext**  current
        as when **bind** () was called on the buffer.

        **See also** **bind** ().
        """
        ...

    @typing.overload
    @staticmethod
    def release(type: "QOpenGLBuffer.Type") -> None:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#release-1

        **[static] void QOpenGLBuffer::release(QOpenGLBuffer::Type type )**

        Releases the buffer associated with **type** in the current
        **QOpenGLContext** .

        This function is a direct call to `glBindBuffer(type, 0)` for use when
        the caller does not know which **QOpenGLBuffer**  has been bound to the
        context but wants to make sure that it is released.

        **QOpenGLBuffer** ::release(**QOpenGLBuffer** ::VertexBuffer);
        """
        ...

    def bind(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#bind

        **bool QOpenGLBuffer::bind()**

        Binds the buffer associated with this object to the current OpenGL
        context. Returns `false` if binding was not possible, usually because
        **type** () is not supported on this OpenGL implementation.

        The buffer must be bound to the same **QOpenGLContext**  current when
        **create** () was called, or to another **QOpenGLContext**  that is
        sharing with it. Otherwise, false will be returned from this function.

        **See also** **release** () and **create** ().
        """
        ...

    def destroy(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#destroy

        **void QOpenGLBuffer::destroy()**

        Destroys this buffer object, including the storage being used in the
        OpenGL server. All references to the buffer will become invalid.
        """
        ...

    def isCreated(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#isCreated

        **bool QOpenGLBuffer::isCreated() const**

        Returns `true` if this buffer has been created; false otherwise.

        **See also** **create** () and **destroy** ().
        """
        ...

    def create(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#create

        **bool QOpenGLBuffer::create()**

        Creates the buffer object in the OpenGL server. Returns `true` if the
        object was created; false otherwise.

        This function must be called with a current **QOpenGLContext** . The
        buffer will be bound to and can only be used in that context (or any
        other context that is shared with it).

        This function will return false if the OpenGL implementation does not
        support buffers, or there is no current **QOpenGLContext** .

        **See also** **isCreated** (), **allocate** (), **write** (), and
        **destroy** ().
        """
        ...

    def setUsagePattern(self, value: "QOpenGLBuffer.UsagePattern") -> None:
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#setUsagePattern

        **void QOpenGLBuffer::setUsagePattern(QOpenGLBuffer::UsagePattern value
        )**

        Sets the usage pattern for this buffer object to **value**. This
        function must be called before **allocate** () or **write** ().

        **See also** **usagePattern** (), **allocate** (), and **write** ().
        """
        ...

    def usagePattern(self) -> "QOpenGLBuffer.UsagePattern":
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#usagePattern

        **QOpenGLBuffer::UsagePattern QOpenGLBuffer::usagePattern() const**

        Returns the usage pattern for this buffer object. The default value is
        **StaticDraw** .

        **See also** **setUsagePattern** ().
        """
        ...

    def type(self) -> "QOpenGLBuffer.Type":
        """
        https://doc.qt.io/qt-6/qopenglbuffer.html#type

        **QOpenGLBuffer::Type QOpenGLBuffer::type() const**

        Returns the type of buffer represented by this object.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._QQuickItem import QQuickItem as QQuickItem
from ._QQuickFramebufferObject import QQuickFramebufferObject as QQuickFramebufferObject
from ._QQuickGraphicsConfiguration import (
    QQuickGraphicsConfiguration as QQuickGraphicsConfiguration,
)
from ._QQuickGraphicsDevice import QQuickGraphicsDevice as QQuickGraphicsDevice
from ._QQuickTextureFactory import QQuickTextureFactory as QQuickTextureFactory
from ._QQuickImageProvider import QQuickImageProvider as QQuickImageProvider
from ._QQuickImageResponse import QQuickImageResponse as QQuickImageResponse
from ._QQuickAsyncImageProvider import (
    QQuickAsyncImageProvider as QQuickAsyncImageProvider,
)
from ._QQuickItemGrabResult import QQuickItemGrabResult as QQuickItemGrabResult
from ._QQuickPaintedItem import QQuickPaintedItem as QQuickPaintedItem
from ._QQuickRenderControl import QQuickRenderControl as QQuickRenderControl
from ._QQuickRenderTarget import QQuickRenderTarget as QQuickRenderTarget
from ._QQuickTextDocument import QQuickTextDocument as QQuickTextDocument
from ._QQuickWindow import QQuickWindow as QQuickWindow
from ._QQuickView import QQuickView as QQuickView
from ._QQuickCloseEvent import QQuickCloseEvent as QQuickCloseEvent
from ._QSGMaterial import QSGMaterial as QSGMaterial
from ._QSGFlatColorMaterial import QSGFlatColorMaterial as QSGFlatColorMaterial
from ._QSGGeometry import QSGGeometry as QSGGeometry
from ._QSGNode import QSGNode as QSGNode
from ._QSGBasicGeometryNode import QSGBasicGeometryNode as QSGBasicGeometryNode
from ._QSGGeometryNode import QSGGeometryNode as QSGGeometryNode
from ._QSGImageNode import QSGImageNode as QSGImageNode
from ._QSGMaterialShader import QSGMaterialShader as QSGMaterialShader
from ._QSGMaterialType import QSGMaterialType as QSGMaterialType
from ._QSGClipNode import QSGClipNode as QSGClipNode
from ._QSGTransformNode import QSGTransformNode as QSGTransformNode
from ._QSGOpacityNode import QSGOpacityNode as QSGOpacityNode
from ._QSGRectangleNode import QSGRectangleNode as QSGRectangleNode
from ._QSGRendererInterface import QSGRendererInterface as QSGRendererInterface
from ._QSGRenderNode import QSGRenderNode as QSGRenderNode
from ._QSGSimpleRectNode import QSGSimpleRectNode as QSGSimpleRectNode
from ._QSGSimpleTextureNode import QSGSimpleTextureNode as QSGSimpleTextureNode
from ._QSGTexture import QSGTexture as QSGTexture
from ._QSGDynamicTexture import QSGDynamicTexture as QSGDynamicTexture
from ._QNativeInterface import QNativeInterface as QNativeInterface
from ._QSGOpaqueTextureMaterial import (
    QSGOpaqueTextureMaterial as QSGOpaqueTextureMaterial,
)
from ._QSGTextureMaterial import QSGTextureMaterial as QSGTextureMaterial
from ._QSGTextureProvider import QSGTextureProvider as QSGTextureProvider
from ._QSGVertexColorMaterial import QSGVertexColorMaterial as QSGVertexColorMaterial



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtGui import *


class QTextTableCell(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtexttablecell.html

    **Detailed Description**

    Table cells are pieces of document structure that belong to a table. The
    table orders cells into particular rows and columns; cells can also span
    multiple columns and rows.

    Cells are usually created when a table is inserted into a document with
    **QTextCursor::insertTable** (), but they are also created and destroyed
    when a table is resized.

    Cells contain information about their location in a table; you can obtain
    the **row** () and **column** () numbers of a cell, and its **rowSpan** ()
    and **columnSpan** ().

    The **format** () of a cell describes the default character format of its
    contents. The **firstCursorPosition** () and **lastCursorPosition** ()
    functions are used to obtain the extent of the cell in the document.

    **See also** **QTextTable**  and **QTextTableFormat** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecell.html#QTextTableCell

        **QTextTableCell::QTextTableCell()**

        Constructs an invalid table cell.

        **See also** **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, o: "QTextTableCell") -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecell.html#QTextTableCell-1

        **QTextTableCell::QTextTableCell(const QTextTableCell & other )**

        Copy constructor. Creates a new QTextTableCell object based on the
        **other** cell.
        """
        ...

    def tableCellFormatIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qtexttablecell.html#tableCellFormatIndex

        **int QTextTableCell::tableCellFormatIndex() const**

        Returns the index of the tableCell's format in the document's internal
        list of formats.

        **See also** **QTextDocument::allFormats** ().
        """
        ...

    def lastCursorPosition(self) -> QTextCursor:
        """
        https://doc.qt.io/qt-6/qtexttablecell.html#lastCursorPosition

        **QTextCursor QTextTableCell::lastCursorPosition() const**

        Returns the last valid cursor position in this cell.

        **See also** **firstCursorPosition** ().
        """
        ...

    def firstCursorPosition(self) -> QTextCursor:
        """
        https://doc.qt.io/qt-6/qtexttablecell.html#firstCursorPosition

        **QTextCursor QTextTableCell::firstCursorPosition() const**

        Returns the first valid cursor position in this cell.

        **See also** **lastCursorPosition** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtexttablecell.html#isValid

        **bool QTextTableCell::isValid() const**

        Returns `true` if this is a valid table cell; otherwise returns false.
        """
        ...

    def columnSpan(self) -> int:
        """
        https://doc.qt.io/qt-6/qtexttablecell.html#columnSpan

        **int QTextTableCell::columnSpan() const**

        Returns the number of columns this cell spans. The default is 1.

        **See also** **rowSpan** ().
        """
        ...

    def rowSpan(self) -> int:
        """
        https://doc.qt.io/qt-6/qtexttablecell.html#rowSpan

        **int QTextTableCell::rowSpan() const**

        Returns the number of rows this cell spans. The default is 1.

        **See also** **columnSpan** ().
        """
        ...

    def column(self) -> int:
        """
        https://doc.qt.io/qt-6/qtexttablecell.html#column

        **int QTextTableCell::column() const**

        Returns the number of the column in the table that contains this cell.

        **See also** **row** ().
        """
        ...

    def row(self) -> int:
        """
        https://doc.qt.io/qt-6/qtexttablecell.html#row

        **int QTextTableCell::row() const**

        Returns the number of the row in the table that contains this cell.

        **See also** **column** ().
        """
        ...

    def setFormat(self, format: QTextCharFormat) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecell.html#setFormat

        **void QTextTableCell::setFormat(const QTextCharFormat & format )**

        Sets the cell's character format to **format**. This can for example be
        used to change the background color of the entire cell:

        **QTextTableCell**  cell = table->cellAt(2, 3); **QTextCharFormat**
        format = cell.**format** (); format.setBackground(**Qt::blue** );
        cell.setFormat(format);

        Note that the cell's row or column span cannot be changed through this
        function. You have to use **QTextTable::mergeCells**  and
        **QTextTable::splitCell**  instead.

        **See also** **format** ().
        """
        ...

    def format(self) -> QTextCharFormat:
        """
        https://doc.qt.io/qt-6/qtexttablecell.html#format

        **QTextCharFormat QTextTableCell::format() const**

        Returns the cell's character format.

        **See also** **setFormat** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtGui import *


class QTextBlockGroup(QTextObject):
    """
    https://doc.qt.io/qt-6/qtextblockgroup.html

    **Detailed Description**

    Block groups can be used to organize blocks of text within a document. They
    maintain an up-to-date list of the text blocks that belong to them, even
    when text blocks are being edited.

    Each group has a parent document which is specified when the group is
    constructed.

    Text blocks can be inserted into a group with **blockInserted** (), and
    removed with **blockRemoved** (). If a block's format is changed,
    **blockFormatChanged** () is called.

    The list of blocks in the group is returned by **blockList** (). Note that
    the blocks in the list are not necessarily adjacent elements in the
    document; for example, the top-level items in a multi-level list will be
    separated by the items in lower levels of the list.

    **See also** **QTextBlock**  and **QTextDocument** .
    """

    def __init__(self, doc: QTextDocument) -> None:
        """
        https://doc.qt.io/qt-6/qtextblockgroup.html#QTextBlockGroup

        **[protected] QTextBlockGroup::QTextBlockGroup(QTextDocument * document
        )**

        Creates a new new block group for the given **document**.

        **Warning:** This function should only be called from
        **QTextDocument::createObject** ().
        """
        ...

    def blockList(self) -> typing.List["QTextBlock"]:
        """
        https://doc.qt.io/qt-6/qtextblockgroup.html#blockList

        **[protected] QList<QTextBlock> QTextBlockGroup::blockList() const**

        Returns a (possibly empty) list of all the blocks that are part of the
        block group.
        """
        ...

    def blockFormatChanged(self, block: "QTextBlock") -> None:
        """
        https://doc.qt.io/qt-6/qtextblockgroup.html#blockFormatChanged

        **[virtual protected] void QTextBlockGroup::blockFormatChanged(const
        QTextBlock & block )**

        This function is called whenever the specified **block** of text is
        changed. The text block is a member of this group.

        The base class implementation does nothing.
        """
        ...

    def blockRemoved(self, block: "QTextBlock") -> None:
        """
        https://doc.qt.io/qt-6/qtextblockgroup.html#blockRemoved

        **[virtual protected] void QTextBlockGroup::blockRemoved(const
        QTextBlock & block )**

        Removes the given **block** from the group; the block itself is not
        deleted, it simply isn't a member of this group anymore.
        """
        ...

    def blockInserted(self, block: "QTextBlock") -> None:
        """
        https://doc.qt.io/qt-6/qtextblockgroup.html#blockInserted

        **[virtual protected] void QTextBlockGroup::blockInserted(const
        QTextBlock & block )**

        Appends the given **block** to the end of the group.

        **Warning:** If you reimplement this function you must call the base
        class implementation.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsSceneMouseEvent(QGraphicsSceneEvent):
    """
    https://doc.qt.io/qt-6/qgraphicsscenemouseevent.html

    **Detailed Description**

    When a **QGraphicsView**  receives a **QMouseEvent** , it translates it to a
    QGraphicsSceneMouseEvent. The event is then forwarded to the
    **QGraphicsScene**  associated with the view. If the event is not handled by
    the scene, the view may use it, e.g., for the **DragMode** .

    In addition to containing the item, scene, and screen coordinates of the
    event (as **pos** (), **scenePos** (), and **screenPos** ()), mouse events
    also contain the coordinates of the previous mouse event received by the
    view. These can be retrieved with **lastPos** (), **lastScreenPos** (), and
    **lastScenePos** ().

    **See also** **QGraphicsSceneContextMenuEvent** ,
    **QGraphicsSceneHoverEvent** , **QGraphicsSceneWheelEvent** , and
    **QMouseEvent** .
    """

    def flags(self) -> QtCore.Qt.MouseEventFlag:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemouseevent.html#flags

        **[since 5.4] Qt::MouseEventFlags QGraphicsSceneMouseEvent::flags()
        const**

        Returns the mouse event flags.

        The mouse event flags provide additional information about a mouse
        event.

        This function was introduced in Qt 5.4.

        **See also** **Qt::MouseEventFlag**  and **QMouseEvent::flags** ().
        """
        ...

    def source(self) -> QtCore.Qt.MouseEventSource:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemouseevent.html#source

        **[since 5.4] Qt::MouseEventSource QGraphicsSceneMouseEvent::source()
        const**

        Returns information about the mouse event source.

        The mouse event source can be used to distinguish between genuine and
        artificial mouse events. The latter are events that are synthesized from
        touch events by the operating system or Qt itself.

        This function was introduced in Qt 5.4.

        **See also** **Qt::MouseEventSource**  and **QMouseEvent::source** ().
        """
        ...

    def modifiers(self) -> QtCore.Qt.KeyboardModifier:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemouseevent.html#modifiers

        **Qt::KeyboardModifiers QGraphicsSceneMouseEvent::modifiers() const**

        Returns the keyboard modifiers in use at the time the event was sent.

        **See also** **buttons** () and **button** ().
        """
        ...

    def button(self) -> QtCore.Qt.MouseButton:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemouseevent.html#button

        **Qt::MouseButton QGraphicsSceneMouseEvent::button() const**

        Returns the mouse button (if any) that caused the event.

        **See also** **buttons** () and **modifiers** ().
        """
        ...

    def buttons(self) -> QtCore.Qt.MouseButton:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemouseevent.html#buttons

        **Qt::MouseButtons QGraphicsSceneMouseEvent::buttons() const**

        Returns the combination of mouse buttons that were pressed at the time
        the event was sent.

        **See also** **button** () and **modifiers** ().
        """
        ...

    def lastScreenPos(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemouseevent.html#lastScreenPos

        **QPoint QGraphicsSceneMouseEvent::lastScreenPos() const**

        Returns the last recorded mouse cursor position in screen coordinates.
        The last recorded position is the position of the previous mouse event
        received by the view that created the event.

        **See also** **lastPos** (), **lastScenePos** (), and **screenPos** ().
        """
        ...

    def lastScenePos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemouseevent.html#lastScenePos

        **QPointF QGraphicsSceneMouseEvent::lastScenePos() const**

        Returns the last recorded mouse cursor position in scene coordinates.
        The last recorded position is the position of the previous mouse event
        received by the view that created the event.

        **See also** **lastPos** (), **lastScreenPos** (), and **scenePos** ().
        """
        ...

    def lastPos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemouseevent.html#lastPos

        **QPointF QGraphicsSceneMouseEvent::lastPos() const**

        Returns the last recorded mouse cursor position in item coordinates.

        **See also** **lastScenePos** (), **lastScreenPos** (), and **pos** ().
        """
        ...

    def buttonDownScreenPos(self, button: QtCore.Qt.MouseButton) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemouseevent.html#buttonDownScreenPos

        **QPoint QGraphicsSceneMouseEvent::buttonDownScreenPos(Qt::MouseButton
        button ) const**

        Returns the mouse cursor position in screen coordinates where the
        specified **button** was clicked.

        **See also** **screenPos** (), **buttonDownPos** (), and
        **buttonDownScenePos** ().
        """
        ...

    def buttonDownScenePos(self, button: QtCore.Qt.MouseButton) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemouseevent.html#buttonDownScenePos

        **QPointF QGraphicsSceneMouseEvent::buttonDownScenePos(Qt::MouseButton
        button ) const**

        Returns the mouse cursor position in scene coordinates where the
        specified **button** was clicked.

        **See also** **buttonDownPos** (), **buttonDownScreenPos** (), and
        **scenePos** ().
        """
        ...

    def buttonDownPos(self, button: QtCore.Qt.MouseButton) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemouseevent.html#buttonDownPos

        **QPointF QGraphicsSceneMouseEvent::buttonDownPos(Qt::MouseButton button
        ) const**

        Returns the mouse cursor position in item coordinates where the
        specified **button** was clicked.

        **See also** **buttonDownScenePos** (), **buttonDownScreenPos** (), and
        **pos** ().
        """
        ...

    def screenPos(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemouseevent.html#screenPos

        **QPoint QGraphicsSceneMouseEvent::screenPos() const**

        Returns the mouse cursor position in screen coordinates.

        **See also** **pos** (), **scenePos** (), and **lastScreenPos** ().
        """
        ...

    def scenePos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemouseevent.html#scenePos

        **QPointF QGraphicsSceneMouseEvent::scenePos() const**

        Returns the mouse cursor position in scene coordinates.

        **See also** **pos** (), **screenPos** (), and **lastScenePos** ().
        """
        ...

    def pos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemouseevent.html#pos

        **QPointF QGraphicsSceneMouseEvent::pos() const**

        Returns the mouse cursor position in item coordinates.

        **See also** **scenePos** (), **screenPos** (), and **lastPos** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6 import QtGui
from PyQt6.QtDesigner import *


class QDesignerCustomWidgetInterface(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdesignercustomwidgetinterface.html

    **Detailed Description**

    QDesignerCustomWidgetInterface provides a custom widget with an interface.
    The class contains a set of functions that must be subclassed to return
    basic information about the widget, such as its class name and the name of
    its header file. Other functions must be implemented to initialize the
    plugin when it is loaded, and to construct instances of the custom widget
    for **Qt Designer** to use.

    When implementing a custom widget you must subclass
    QDesignerCustomWidgetInterface to expose your widget to **Qt Designer**. For
    example, this is the declaration for the plugin used in the **Custom Widget
    Plugin example**  that enables an analog clock custom widget to be used by
    **Qt Designer** :

    class AnalogClockPlugin : public **QObject** , public
    **QDesignerCustomWidgetInterface**
        {
            Q_OBJECT
    Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QDesignerCustomWidgetInterface")
    Q_INTERFACES(**QDesignerCustomWidgetInterface** )
        public:
    explicit AnalogClockPlugin(**QObject**  *parent = nullptr);
    bool isContainer() const override;
            bool isInitialized() const
    override;
            **QIcon**  icon() const override;
            **QString**
    domXml() const override;
            **QString**  group() const override;
    **QString**  includeFile() const override;
            **QString**  name() const
    override;
            **QString**  toolTip() const override;
            **QString**
    whatsThis() const override;
            **QWidget**  *createWidget(**QWidget**
    *parent) override;
            void initialize(**QDesignerFormEditorInterface**
    *core) override;

        private:
            bool initialized = false;
        };

    Note that the only part of the class definition that is specific to this
    particular custom widget is the class name. In addition, since we are
    implementing an interface, we must ensure that it's made known to the meta
    object system using the **Q_INTERFACES** () macro. This enables **Qt
    Designer** to use the **qobject_cast** () function to query for supported
    interfaces using nothing but a **QObject**  pointer.

    After **Qt Designer** loads a custom widget plugin, it calls the interface's
    **initialize** () function to enable it to set up any resources that it may
    need. This function is called with a **QDesignerFormEditorInterface**
    parameter that provides the plugin with a gateway to all of **Qt Designer**
    's API.

    **Qt Designer** constructs instances of the custom widget by calling the
    plugin's **createWidget** () function with a suitable parent widget. Plugins
    must construct and return an instance of a custom widget with the specified
    parent widget.

    Exporting your custom widget plugin to **Qt Designer** using the
    **Q_PLUGIN_METADATA** () macro. For example, if a library called
    `libcustomwidgetplugin.so` (on Unix) or `libcustomwidget.dll` (on Windows)
    contains a widget class called `MyCustomWidget`, we can export it by adding
    the following line to the file containing the plugin header:

    Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QDesignerCustomWidgetInterface")

    This macro ensures that **Qt Designer** can access and construct the custom
    widget. Without this macro, there is no way for **Qt Designer** to use it.

    When implementing a custom widget plugin, you build it as a separate
    library. If you want to include several custom widget plugins in the same
    library, you must in addition subclass
    **QDesignerCustomWidgetCollectionInterface** .

    **Warning:** If your custom widget plugin contains **QVariant**  properties,
    be aware that only the following **types**  are supported:

    * QVariant::ByteArray
      * QVariant::Bool
      * QVariant::Color
      *
    QVariant::Cursor
      * QVariant::Date
      * QVariant::DateTime
      *
    QVariant::Double
      * QVariant::Int
      * QVariant::Point
      * QVariant::Rect
    * QVariant::Size
      * QVariant::SizePolicy
      * QVariant::String
      *
    QVariant::Time
      * QVariant::UInt

    For a complete example using the QDesignerCustomWidgetInterface class, see
    the **Custom Widget Example** . The example shows how to create a custom
    widget plugin for **Qt Designer**.

    **See also** **QDesignerCustomWidgetCollectionInterface**  and **Creating
    Custom Widgets for Qt Designer** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QDesignerCustomWidgetInterface") -> None:
        ...

    def codeTemplate(self) -> str:
        """
        https://doc.qt.io/qt-6/qdesignercustomwidgetinterface.html#codeTemplate

        **[virtual] QString QDesignerCustomWidgetInterface::codeTemplate()
        const**

        This function is reserved for future use by **Qt Designer**.
        """
        ...

    def domXml(self) -> str:
        """
        https://doc.qt.io/qt-6/qdesignercustomwidgetinterface.html#domXml

        **[virtual] QString QDesignerCustomWidgetInterface::domXml() const**

        Returns the XML that is used to describe the custom widget's properties
        to **Qt Designer**.
        """
        ...

    def initialize(self, core: QDesignerFormEditorInterface) -> None:
        """
        https://doc.qt.io/qt-6/qdesignercustomwidgetinterface.html#initialize

        **[virtual] void
        QDesignerCustomWidgetInterface::initialize(QDesignerFormEditorInterface
        * formEditor )**

        Initializes the widget for use with the specified **formEditor**
        interface.

        **See also** **isInitialized** ().
        """
        ...

    def isInitialized(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignercustomwidgetinterface.html#isInitialized

        **[virtual] bool QDesignerCustomWidgetInterface::isInitialized() const**

        Returns true if the widget has been initialized; otherwise returns
        false.

        **See also** **initialize** ().
        """
        ...

    def createWidget(self, parent: QtWidgets.QWidget) -> QtWidgets.QWidget:
        """
        https://doc.qt.io/qt-6/qdesignercustomwidgetinterface.html#createWidget

        **[pure virtual] QWidget
        *QDesignerCustomWidgetInterface::createWidget(QWidget * parent )**

        Returns a new instance of the custom widget, with the given **parent**.
        """
        ...

    def isContainer(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignercustomwidgetinterface.html#isContainer

        **[pure virtual] bool QDesignerCustomWidgetInterface::isContainer()
        const**

        Returns true if the custom widget is intended to be used as a container;
        otherwise returns false.

        Most custom widgets are not used to hold other widgets, so their
        implementations of this function will return false, but custom
        containers will return true to ensure that they behave correctly in **Qt
        Designer**.
        """
        ...

    def icon(self) -> QtGui.QIcon:
        """
        https://doc.qt.io/qt-6/qdesignercustomwidgetinterface.html#icon

        **[pure virtual] QIcon QDesignerCustomWidgetInterface::icon() const**

        Returns the icon used to represent the custom widget in **Qt Designer**
        's widget box.
        """
        ...

    def includeFile(self) -> str:
        """
        https://doc.qt.io/qt-6/qdesignercustomwidgetinterface.html#includeFile

        **[pure virtual] QString QDesignerCustomWidgetInterface::includeFile()
        const**

        Returns the path to the include file that **uic**  uses when creating
        code for the custom widget.
        """
        ...

    def whatsThis(self) -> str:
        """
        https://doc.qt.io/qt-6/qdesignercustomwidgetinterface.html#whatsThis

        **[pure virtual] QString QDesignerCustomWidgetInterface::whatsThis()
        const**

        Returns a description of the widget that can be used by **Qt Designer**
        in "What's This?" help for the widget.
        """
        ...

    def toolTip(self) -> str:
        """
        https://doc.qt.io/qt-6/qdesignercustomwidgetinterface.html#toolTip

        **[pure virtual] QString QDesignerCustomWidgetInterface::toolTip()
        const**

        Returns a short description of the widget that can be used by **Qt
        Designer** in a tool tip.
        """
        ...

    def group(self) -> str:
        """
        https://doc.qt.io/qt-6/qdesignercustomwidgetinterface.html#group

        **[pure virtual] QString QDesignerCustomWidgetInterface::group() const**

        Returns the name of the group to which the custom widget belongs.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qdesignercustomwidgetinterface.html#name

        **[pure virtual] QString QDesignerCustomWidgetInterface::name() const**

        Returns the class name of the custom widget supplied by the interface.

        The name returned **must** be identical to the class name used for the
        custom widget.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QDrag(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qdrag.html

    **Detailed Description**

    Drag and drop is an intuitive way for users to copy or move data around in
    an application, and is used in many desktop environments as a mechanism for
    copying data between applications. Drag and drop support in Qt is centered
    around the QDrag class that handles most of the details of a drag and drop
    operation.

    The data to be transferred by the drag and drop operation is contained in a
    **QMimeData**  object. This is specified with the **setMimeData** ()
    function in the following way:

    **QDrag**  *drag = new **QDrag** (this);
                **QMimeData**
    *mimeData = new **QMimeData** ;
    mimeData->setText(commentEdit->toPlainText());
    drag->setMimeData(mimeData);

    Note that **setMimeData** () assigns ownership of the **QMimeData**  object
    to the QDrag object. The QDrag must be constructed on the heap with a parent
    **QObject**  to ensure that Qt can clean up after the drag and drop
    operation has been completed.

    A pixmap can be used to represent the data while the drag is in progress,
    and will move with the cursor to the drop target. This pixmap typically
    shows an icon that represents the MIME type of the data being transferred,
    but any pixmap can be set with **setPixmap** (). The cursor's hot spot can
    be given a position relative to the top-left corner of the pixmap with the
    **setHotSpot** () function. The following code positions the pixmap so that
    the cursor's hot spot points to the center of its bottom edge:

    drag->setHotSpot(**QPoint** (drag->pixmap().width()/2,
    drag->pixmap().height()));

    **Note:** On X11, the pixmap may not be able to keep up with the mouse
    movements if the hot spot causes the pixmap to be displayed directly under
    the cursor.

    The source and target widgets can be found with **source** () and **target**
    (). These functions are often used to determine whether drag and drop
    operations started and finished at the same widget, so that special behavior
    can be implemented.

    QDrag only deals with the drag and drop operation itself. It is up to the
    developer to decide when a drag operation begins, and how a QDrag object
    should be constructed and used. For a given widget, it is often necessary to
    reimplement **mousePressEvent** () to determine whether the user has pressed
    a mouse button, and reimplement **mouseMoveEvent** () to check whether a
    QDrag is required.

    **See also** **Drag and Drop** , **QClipboard** , **QMimeData** ,
    **Draggable Icons Example** , **Draggable Text Example** , **Drop Site
    Example** , and **Fridge Magnets Example** .
    """

    def __init__(self, dragSource: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qdrag.html#QDrag

        **QDrag::QDrag(QObject * dragSource )**

        Constructs a new drag object for the widget specified by **dragSource**.
        """
        ...

    @staticmethod
    def cancel() -> None:
        """
        https://doc.qt.io/qt-6/qdrag.html#cancel

        **[static, since 5.7] void QDrag::cancel()**

        Cancels a drag operation initiated by Qt.

        **Note:** This is currently implemented on Windows and X11.

        This function was introduced in Qt 5.7.

        **See also** **exec** ().
        """
        ...

    def defaultAction(self) -> QtCore.Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qdrag.html#defaultAction

        **Qt::DropAction QDrag::defaultAction() const**

        Returns the default proposed drop action for this drag operation.

        **See also** **exec** () and **supportedActions** ().
        """
        ...

    def supportedActions(self) -> QtCore.Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qdrag.html#supportedActions

        **Qt::DropActions QDrag::supportedActions() const**

        Returns the set of possible drop actions for this drag operation.

        **See also** **exec** () and **defaultAction** ().
        """
        ...

    def dragCursor(self, action: QtCore.Qt.DropAction) -> QPixmap:
        """
        https://doc.qt.io/qt-6/qdrag.html#dragCursor

        **[since 5.0] QPixmap QDrag::dragCursor(Qt::DropAction action ) const**

        Returns the drag cursor for the **action**.

        This function was introduced in Qt 5.0.

        **See also** **setDragCursor** ().
        """
        ...

    def setDragCursor(self, cursor: QPixmap, action: QtCore.Qt.DropAction) -> None:
        """
        https://doc.qt.io/qt-6/qdrag.html#setDragCursor

        **void QDrag::setDragCursor(const QPixmap & cursor , Qt::DropAction
        action )**

        Sets the drag **cursor** for the **action**. This allows you to override
        the default native cursors. To revert to using the native cursor for
        **action** pass in a null **QPixmap**  as **cursor**.

        Note: setting the drag cursor for IgnoreAction may not work on all
        platforms. X11 and macOS has been tested to work. Windows does not
        support it.

        **See also** **dragCursor** ().
        """
        ...

    def target(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qdrag.html#target

        **QObject *QDrag::target() const**

        Returns the target of the drag and drop operation. This is the widget
        where the drag object was dropped.
        """
        ...

    def source(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qdrag.html#source

        **QObject *QDrag::source() const**

        Returns the source of the drag object. This is the widget where the drag
        and drop operation originated.
        """
        ...

    def hotSpot(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qdrag.html#hotSpot

        **QPoint QDrag::hotSpot() const**

        Returns the position of the hot spot relative to the top-left corner of
        the cursor.

        **See also** **setHotSpot** ().
        """
        ...

    def setHotSpot(self, hotspot: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qdrag.html#setHotSpot

        **void QDrag::setHotSpot(const QPoint & hotspot )**

        Sets the position of the hot spot relative to the top-left corner of the
        pixmap used to the point specified by **hotspot**.

        **Note:** on X11, the pixmap may not be able to keep up with the mouse
        movements if the hot spot causes the pixmap to be displayed directly
        under the cursor.

        **See also** **hotSpot** ().
        """
        ...

    def pixmap(self) -> QPixmap:
        """
        https://doc.qt.io/qt-6/qdrag.html#pixmap

        **QPixmap QDrag::pixmap() const**

        Returns the pixmap used to represent the data in a drag and drop
        operation.

        **See also** **setPixmap** ().
        """
        ...

    def setPixmap(self, a0: QPixmap) -> None:
        """
        https://doc.qt.io/qt-6/qdrag.html#setPixmap

        **void QDrag::setPixmap(const QPixmap & pixmap )**

        Sets **pixmap** as the pixmap used to represent the data in a drag and
        drop operation. You can only set a pixmap before the drag is started.

        **See also** **pixmap** ().
        """
        ...

    def mimeData(self) -> QtCore.QMimeData:
        """
        https://doc.qt.io/qt-6/qdrag.html#mimeData

        **QMimeData *QDrag::mimeData() const**

        Returns the MIME data that is encapsulated by the drag object.

        **See also** **setMimeData** ().
        """
        ...

    def setMimeData(self, data: QtCore.QMimeData) -> None:
        """
        https://doc.qt.io/qt-6/qdrag.html#setMimeData

        **void QDrag::setMimeData(QMimeData * data )**

        Sets the data to be sent to the given MIME **data**. Ownership of the
        data is transferred to the **QDrag**  object.

        **See also** **mimeData** ().
        """
        ...

    @typing.overload
    def exec(
        self, supportedActions: QtCore.Qt.DropAction = ...
    ) -> QtCore.Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qdrag.html#exec

        **Qt::DropAction QDrag::exec(Qt::DropActions supportedActions =
        Qt::MoveAction)**

        Starts the drag and drop operation and returns a value indicating the
        requested drop action when it is completed. The drop actions that the
        user can choose from are specified in **supportedActions**. The default
        proposed action will be selected among the allowed actions in the
        following order: Move, Copy and Link.

        **Note:** On Linux and macOS, the drag and drop operation can take some
        time, but this function does not block the event loop. Other events are
        still delivered to the application while the operation is performed. On
        Windows, the Qt event loop is blocked during the operation.

        **See also** **cancel** ().
        """
        ...

    @typing.overload
    def exec(
        self,
        supportedActions: QtCore.Qt.DropAction,
        defaultDropAction: QtCore.Qt.DropAction,
    ) -> QtCore.Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qdrag.html#exec-1

        **Qt::DropAction QDrag::exec(Qt::DropActions supportedActions ,
        Qt::DropAction defaultDropAction )**

        Starts the drag and drop operation and returns a value indicating the
        requested drop action when it is completed. The drop actions that the
        user can choose from are specified in **supportedActions**.

        The **defaultDropAction** determines which action will be proposed when
        the user performs a drag without using modifier keys.

        **Note:** On Linux and macOS, the drag and drop operation can take some
        time, but this function does not block the event loop. Other events are
        still delivered to the application while the operation is performed. On
        Windows, the Qt event loop is blocked during the operation. However,
        **QDrag::exec** () on Windows causes processEvents() to be called
        frequently to keep the GUI responsive. If any loops or operations are
        called while a drag operation is active, it will block the drag
        operation.
        """
        ...

    @property
    def actionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdrag.html#actionChanged

        **[signal] void QDrag::actionChanged(Qt::DropAction action )**

        This signal is emitted when the **action** associated with the drag
        changes.

        **See also** **targetChanged** ().
        """
        ...

    @property
    def targetChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdrag.html#targetChanged

        **[signal] void QDrag::targetChanged(QObject * newTarget )**

        This signal is emitted when the target of the drag and drop operation
        changes, with **newTarget** the new target.

        **See also** **target** () and **actionChanged** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
import datetime
from PyQt6.QtCore import *
import enum


class QTimeZone(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtimezone.html

    **Detailed Description**

    This class provides a stateless calculator for time zone conversions between
    UTC and the local time in a specific time zone. By default it uses the host
    system time zone data to perform these conversions.

    This class is primarily designed for use in **QDateTime** ; most
    applications will not need to access this class directly and should instead
    use **QDateTime**  with a **Qt::TimeSpec**  of **Qt::TimeZone** .

    **Note:** For consistency with **QDateTime** , QTimeZone does not account
    for leap seconds.

    **Remarks**

    **IANA Time Zone IDs**

    QTimeZone uses the IANA time zone IDs as defined in the IANA Time Zone
    Database (http://www.iana.org/time-zones). This is to ensure a standard ID
    across all supported platforms. Most platforms support the IANA IDs and the
    IANA Database natively, but for Windows a mapping is required to the native
    IDs. See below for more details.

    The IANA IDs can and do change on a regular basis, and can vary depending on
    how recently the host system data was updated. As such you cannot rely on
    any given ID existing on any host system. You must use
    **availableTimeZoneIds** () to determine what IANA IDs are available.

    The IANA IDs and database are also know as the Olson IDs and database, named
    after their creator.

    **UTC Offset Time Zones**

    A default UTC time zone backend is provided which is always guaranteed to be
    available. This provides a set of generic Offset From UTC time zones in the
    range UTC-14:00 to UTC+14:00. These time zones can be created using either
    the standard ISO format names "UTC+00:00" as listed by
    **availableTimeZoneIds** (), or using the number of offset seconds.

    **Windows Time Zones**

    Windows native time zone support is severely limited compared to the
    standard IANA TZ Database. Windows time zones cover larger geographic areas
    and are thus less accurate in their conversions. They also do not support as
    much historic conversion data and so may only be accurate for the current
    year.

    QTimeZone uses a conversion table derived form the Unicode CLDR data to map
    between IANA IDs and Windows IDs. Depending on your version of Windows and
    Qt, this table may not be able to provide a valid conversion, in which "UTC"
    will be returned.

    QTimeZone provides a public API to use this conversion table. The Windows ID
    used is the Windows Registry Key for the time zone which is also the MS
    Exchange EWS ID as well, but is different to the Time Zone Name (TZID) and
    COD code used by MS Exchange in versions before 2007.

    **System Time Zone**

    QTimeZone does not support any concept of a system or default time zone. If
    you require a **QDateTime**  that uses the current system time zone at any
    given moment then you should use a **Qt::TimeSpec**  of **Qt::LocalTime** .

    The method **systemTimeZoneId** () returns the current system IANA time zone
    ID which on Unix-like systems will always be correct. On Windows this ID is
    translated from the Windows system ID using an internal translation table
    and the user's selected country. As a consequence there is a small chance
    any Windows install may have IDs not known by Qt, in which case "UTC" will
    be returned.

    Creating a new QTimeZone instance using the system time zone ID will only
    produce a fixed named copy of the time zone, it will not change if the
    system time zone changes.

    **Time Zone Offsets**

    The difference between UTC and the local time in a time zone is expressed as
    an offset in seconds from UTC, i.e. the number of seconds to add to UTC to
    obtain the local time. The total offset is comprised of two component parts,
    the standard time offset and the daylight-saving time offset. The standard
    time offset is the number of seconds to add to UTC to obtain standard time
    in the time zone. The daylight-saving time offset is the number of seconds
    to add to the standard time offset to obtain daylight-saving time
    (abbreviated DST and sometimes called "daylight time" or "summer time") in
    the time zone.

    Note that the standard and DST offsets for a time zone may change over time
    as countries have changed DST laws or even their standard time offset.

    **License**

    This class includes data obtained from the CLDR data files under the terms
    of the Unicode Data Files and Software License. See **Unicode Common Locale
    Data Repository (CLDR)**  for details.

    **See also** **QDateTime** .
    """

    class NameType(enum.Enum):
        DefaultName: QTimeZone = ...
        LongName: QTimeZone = ...
        ShortName: QTimeZone = ...
        OffsetName: QTimeZone = ...

    class TimeType(enum.Enum):
        StandardTime: QTimeZone = ...
        DaylightTime: QTimeZone = ...
        GenericTime: QTimeZone = ...

    class OffsetData(PyQt6.sip.simplewrapper):
        abbreviation: str = ...
        atUtc: typing = ...
        daylightTimeOffset: int = ...
        offsetFromUtc: int = ...
        standardTimeOffset: int = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QTimeZone.OffsetData") -> None:
            ...

    @typing.overload
    def __init__(
        self,
        zoneId: QByteArray,
        offsetSeconds: int,
        name: str,
        abbreviation: str,
        territory: QLocale.Country = ...,
        comment: str = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtimezone.html#QTimeZone

        **QTimeZone::QTimeZone()**

        Create a null/invalid time zone instance.
        """
        ...

    @typing.overload
    def __init__(self, ianaId: QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qtimezone.html#QTimeZone-1

        **QTimeZone::QTimeZone(const QByteArray & ianaId )**

        Creates an instance of the requested time zone **ianaId**.

        The ID must be one of the available system IDs or a valid UTC-with-
        offset ID, otherwise an invalid time zone will be returned.

        **See also** **availableTimeZoneIds** ().
        """
        ...

    @typing.overload
    def __init__(self, offsetSeconds: int) -> None:
        """
        https://doc.qt.io/qt-6/qtimezone.html#QTimeZone-2

        **QTimeZone::QTimeZone(int offsetSeconds )**

        Creates an instance of a time zone with the requested Offset from UTC of
        **offsetSeconds**.

        The **offsetSeconds** from UTC must be in the range -14 hours to +14
        hours otherwise an invalid time zone will be returned.
        """
        ...

    @typing.overload
    def __init__(self, other: "QTimeZone") -> None:
        """
        https://doc.qt.io/qt-6/qtimezone.html#QTimeZone-3

        **QTimeZone::QTimeZone(const QByteArray & ianaId , int offsetSeconds ,
        const QString & name , const QString & abbreviation , QLocale::Territory
        territory = QLocale::AnyTerritory, const QString & comment =
        QString())**

        Creates a custom time zone with an ID of **ianaId** and an offset from
        UTC of **offsetSeconds**. The **name** will be the name used by
        **displayName** () for the **LongName** , the **abbreviation** will be
        used by **displayName** () for the **ShortName**  and by
        **abbreviation** (), and the optional **territory** will be used by
        **territory** (). The **comment** is an optional note that may be
        displayed in a GUI to assist users in selecting a time zone.

        The **ianaId** must not be one of the available system IDs returned by
        **availableTimeZoneIds** (). The **offsetSeconds** from UTC must be in
        the range -14 hours to +14 hours.

        If the custom time zone does not have a specific territory then set it
        to the default value of **QLocale::AnyTerritory** .
        """
        ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtimezone.html#QTimeZone-4

        **QTimeZone::QTimeZone(const QTimeZone & other )**

        Copy constructor, copy **other** to this.
        """
        ...

    @staticmethod
    def utc() -> "QTimeZone":
        """
        https://doc.qt.io/qt-6/qtimezone.html#utc

        **[static, since 5.5] QTimeZone QTimeZone::utc()**

        Returns a **QTimeZone**  object that refers to UTC (Universal Time
        Coordinated).

        This function was introduced in Qt 5.5.

        **See also** **systemTimeZone** ().
        """
        ...

    @staticmethod
    def systemTimeZone() -> "QTimeZone":
        """
        https://doc.qt.io/qt-6/qtimezone.html#systemTimeZone

        **[static, since 5.5] QTimeZone QTimeZone::systemTimeZone()**

        Returns a **QTimeZone**  object that refers to the local system time, as
        specified by **systemTimeZoneId** ().

        This function was introduced in Qt 5.5.

        **See also** **utc** ().
        """
        ...

    @typing.overload
    @staticmethod
    def windowsIdToIanaIds(windowsId: QByteArray) -> typing.List[QByteArray]:
        """
        https://doc.qt.io/qt-6/qtimezone.html#windowsIdToIanaIds

        **[static] QList<QByteArray> QTimeZone::windowsIdToIanaIds(const
        QByteArray & windowsId )**

        Returns all the IANA IDs for a given **windowsId**.

        The returned list is sorted alphabetically.

        **See also** **ianaIdToWindowsId** () and **windowsIdToDefaultIanaId**
        ().
        """
        ...

    @typing.overload
    @staticmethod
    def windowsIdToIanaIds(
        windowsId: QByteArray, territory: QLocale.Country
    ) -> typing.List[QByteArray]:
        """
        https://doc.qt.io/qt-6/qtimezone.html#windowsIdToIanaIds-1

        **[static] QList<QByteArray> QTimeZone::windowsIdToIanaIds(const
        QByteArray & windowsId , QLocale::Territory territory )**

        Returns all the IANA IDs for a given **windowsId** and **territory**.

        As a special case **QLocale::AnyTerritory**  returns those IANA IDs that
        do not have any specific territory.

        The returned list is in order of frequency of usage, i.e. larger zones
        within a territory are listed first.

        **See also** **ianaIdToWindowsId** () and **windowsIdToDefaultIanaId**
        ().
        """
        ...

    @typing.overload
    @staticmethod
    def windowsIdToDefaultIanaId(windowsId: QByteArray) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qtimezone.html#windowsIdToDefaultIanaId

        **[static] QByteArray QTimeZone::windowsIdToDefaultIanaId(const
        QByteArray & windowsId )**

        Returns the default IANA ID for a given **windowsId**.

        Because a Windows ID can cover several IANA IDs in several different
        countries, this function returns the most frequently used IANA ID with
        no regard for the country and should thus be used with care. It is
        usually best to request the default for a specific country.

        **See also** **ianaIdToWindowsId** () and **windowsIdToIanaIds** ().
        """
        ...

    @typing.overload
    @staticmethod
    def windowsIdToDefaultIanaId(
        windowsId: QByteArray, territory: QLocale.Country
    ) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qtimezone.html#windowsIdToDefaultIanaId-1

        **[static] QByteArray QTimeZone::windowsIdToDefaultIanaId(const
        QByteArray & windowsId , QLocale::Territory territory )**

        Returns the default IANA ID for a given **windowsId** and **territory**.

        Because a Windows ID can cover several IANA IDs within a given
        territory, the most frequently used IANA ID in that territory is
        returned.

        As a special case, **QLocale::AnyTerritory**  returns the default of
        those IANA IDs that do not have any specific territory.

        **See also** **ianaIdToWindowsId** () and **windowsIdToIanaIds** ().
        """
        ...

    @staticmethod
    def ianaIdToWindowsId(ianaId: QByteArray) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qtimezone.html#ianaIdToWindowsId

        **[static] QByteArray QTimeZone::ianaIdToWindowsId(const QByteArray &
        ianaId )**

        Returns the Windows ID equivalent to the given **ianaId**.

        **See also** **windowsIdToDefaultIanaId** () and **windowsIdToIanaIds**
        ().
        """
        ...

    @typing.overload
    @staticmethod
    def availableTimeZoneIds(territory: QLocale.Country) -> typing.List[QByteArray]:
        """
        https://doc.qt.io/qt-6/qtimezone.html#availableTimeZoneIds

        **[static] QList<QByteArray> QTimeZone::availableTimeZoneIds()**

        Returns a list of all available IANA time zone IDs on this system.

        **See also** **isTimeZoneIdAvailable** ().
        """
        ...

    @typing.overload
    @staticmethod
    def availableTimeZoneIds(offsetSeconds: int) -> typing.List[QByteArray]:
        """
        https://doc.qt.io/qt-6/qtimezone.html#availableTimeZoneIds-1

        **[static] QList<QByteArray>
        QTimeZone::availableTimeZoneIds(QLocale::Territory territory )**

        Returns a list of all available IANA time zone IDs for a given
        **territory**.

        As a special case, a **territory** of Qt::AnyTerritory returns those
        time zones that do not have any territory related to them, such as UTC.
        If you require a list of all time zone IDs for all countries then use
        the standard availableTimeZoneIds() method.

        **See also** **isTimeZoneIdAvailable** ().
        """
        ...

    @typing.overload
    @staticmethod
    def availableTimeZoneIds() -> typing.List[QByteArray]:
        """
        https://doc.qt.io/qt-6/qtimezone.html#availableTimeZoneIds-2

        **[static] QList<QByteArray> QTimeZone::availableTimeZoneIds(int
        offsetSeconds )**

        Returns a list of all available IANA time zone IDs with a given standard
        time offset of **offsetSeconds**.

        **See also** **isTimeZoneIdAvailable** ().
        """
        ...

    @staticmethod
    def isTimeZoneIdAvailable(ianaId: QByteArray) -> bool:
        """
        https://doc.qt.io/qt-6/qtimezone.html#isTimeZoneIdAvailable

        **[static] bool QTimeZone::isTimeZoneIdAvailable(const QByteArray &
        ianaId )**

        Returns `true` if a given time zone **ianaId** is available on this
        system.

        **See also** **availableTimeZoneIds** ().
        """
        ...

    @staticmethod
    def systemTimeZoneId() -> QByteArray:
        """
        https://doc.qt.io/qt-6/qtimezone.html#systemTimeZoneId

        **[static] QByteArray QTimeZone::systemTimeZoneId()**

        Returns the current system time zone IANA ID.

        On Windows this ID is translated from the Windows ID using an internal
        translation table and the user's selected country. As a consequence
        there is a small chance any Windows install may have IDs not known by
        Qt, in which case "UTC" will be returned.
        """
        ...

    def transitions(
        self,
        fromDateTime: typing.Union[QDateTime, datetime.datetime],
        toDateTime: typing.Union[QDateTime, datetime.datetime],
    ) -> typing.List["QTimeZone.OffsetData"]:
        """
        https://doc.qt.io/qt-6/qtimezone.html#transitions

        **QTimeZone::OffsetDataList QTimeZone::transitions(const QDateTime &
        fromDateTime , const QDateTime & toDateTime ) const**

        Returns a list of all time zone transitions between the given datetimes.

        The given **fromDateTime** and **toDateTime** are inclusive.

        **See also** **hasTransitions** (), **nextTransition** (), and
        **previousTransition** ().
        """
        ...

    def previousTransition(
        self, beforeDateTime: typing.Union[QDateTime, datetime.datetime]
    ) -> "QTimeZone.OffsetData":
        """
        https://doc.qt.io/qt-6/qtimezone.html#previousTransition

        **QTimeZone::OffsetData QTimeZone::previousTransition(const QDateTime &
        beforeDateTime ) const**

        Returns the first time zone Transition before the given
        **beforeDateTime**. This is most useful when you have a Transition time
        and wish to find the Transition before it.

        If there is no transition before the given **beforeDateTime** then an
        invalid **OffsetData**  will be returned with an invalid **QDateTime** .

        The given **beforeDateTime** is exclusive.

        **See also** **hasTransitions** (), **nextTransition** (), and
        **transitions** ().
        """
        ...

    def nextTransition(
        self, afterDateTime: typing.Union[QDateTime, datetime.datetime]
    ) -> "QTimeZone.OffsetData":
        """
        https://doc.qt.io/qt-6/qtimezone.html#nextTransition

        **QTimeZone::OffsetData QTimeZone::nextTransition(const QDateTime &
        afterDateTime ) const**

        Returns the first time zone Transition after the given
        **afterDateTime**. This is most useful when you have a Transition time
        and wish to find the Transition after it.

        If there is no transition after the given **afterDateTime** then an
        invalid **OffsetData**  will be returned with an invalid **QDateTime** .

        The given **afterDateTime** is exclusive.

        **See also** **hasTransitions** (), **previousTransition** (), and
        **transitions** ().
        """
        ...

    def hasTransitions(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtimezone.html#hasTransitions

        **bool QTimeZone::hasTransitions() const**

        Returns `true` if the system backend supports obtaining transitions.

        Transitions are changes in the time-zone: these happen when DST turns on
        or off and when authorities alter the offsets for the time-zone.

        **See also** **nextTransition** (), **previousTransition** (), and
        **transitions** ().
        """
        ...

    def offsetData(
        self, forDateTime: typing.Union[QDateTime, datetime.datetime]
    ) -> "QTimeZone.OffsetData":
        """
        https://doc.qt.io/qt-6/qtimezone.html#offsetData

        **QTimeZone::OffsetData QTimeZone::offsetData(const QDateTime &
        forDateTime ) const**

        Returns the effective offset details at the given **forDateTime**. This
        is the equivalent of calling **offsetFromUtc** (), **abbreviation** (),
        etc individually but is more efficient.

        **See also** **offsetFromUtc** (), **standardTimeOffset** (),
        **daylightTimeOffset** (), and **abbreviation** ().
        """
        ...

    def isDaylightTime(
        self, atDateTime: typing.Union[QDateTime, datetime.datetime]
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtimezone.html#isDaylightTime

        **bool QTimeZone::isDaylightTime(const QDateTime & atDateTime ) const**

        Returns `true` if daylight-saving was in effect at the given
        **atDateTime**.

        **See also** **hasDaylightTime** () and **daylightTimeOffset** ().
        """
        ...

    def hasDaylightTime(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtimezone.html#hasDaylightTime

        **bool QTimeZone::hasDaylightTime() const**

        Returns `true` if the time zone has practiced daylight-saving at any
        time.

        **See also** **isDaylightTime** () and **daylightTimeOffset** ().
        """
        ...

    def daylightTimeOffset(
        self, atDateTime: typing.Union[QDateTime, datetime.datetime]
    ) -> int:
        """
        https://doc.qt.io/qt-6/qtimezone.html#daylightTimeOffset

        **int QTimeZone::daylightTimeOffset(const QDateTime & atDateTime )
        const**

        Returns the daylight-saving time offset at the given **atDateTime** ,
        i.e. the number of seconds to add to the standard time offset to obtain
        the local daylight-saving time.

        For example, for the time zone "Europe/Berlin" the DST offset is +3600
        seconds. During standard time daylightTimeOffset() will return 0, and
        when daylight-saving is in effect it will return +3600.

        **See also** **offsetFromUtc** () and **standardTimeOffset** ().
        """
        ...

    def standardTimeOffset(
        self, atDateTime: typing.Union[QDateTime, datetime.datetime]
    ) -> int:
        """
        https://doc.qt.io/qt-6/qtimezone.html#standardTimeOffset

        **int QTimeZone::standardTimeOffset(const QDateTime & atDateTime )
        const**

        Returns the standard time offset at the given **atDateTime** , i.e. the
        number of seconds to add to UTC to obtain the local Standard Time. This
        excludes any DST offset that may be in effect.

        For example, for the time zone "Europe/Berlin" the standard time offset
        is +3600 seconds. During both standard and DST **offsetFromUtc** () will
        return +3600 (UTC+01:00).

        **See also** **offsetFromUtc** () and **daylightTimeOffset** ().
        """
        ...

    def offsetFromUtc(
        self, atDateTime: typing.Union[QDateTime, datetime.datetime]
    ) -> int:
        """
        https://doc.qt.io/qt-6/qtimezone.html#offsetFromUtc

        **int QTimeZone::offsetFromUtc(const QDateTime & atDateTime ) const**

        Returns the total effective offset at the given **atDateTime** , i.e.
        the number of seconds to add to UTC to obtain the local time. This
        includes any DST offset that may be in effect, i.e. it is the sum of
        **standardTimeOffset** () and **daylightTimeOffset** () for the given
        datetime.

        For example, for the time zone "Europe/Berlin" the standard time offset
        is +3600 seconds and the DST offset is +3600 seconds. During standard
        time offsetFromUtc() will return +3600 (UTC+01:00), and during DST it
        will return +7200 (UTC+02:00).

        **See also** **standardTimeOffset** () and **daylightTimeOffset** ().
        """
        ...

    def abbreviation(
        self, atDateTime: typing.Union[QDateTime, datetime.datetime]
    ) -> str:
        """
        https://doc.qt.io/qt-6/qtimezone.html#abbreviation

        **QString QTimeZone::abbreviation(const QDateTime & atDateTime ) const**

        Returns the time zone abbreviation at the given **atDateTime**. The
        abbreviation may change depending on DST or even historical events.

        Note that the abbreviation is not guaranteed to be unique to this time
        zone and should not be used in place of the ID or display name.

        **See also** **displayName** ().
        """
        ...

    @typing.overload
    def displayName(
        self,
        atDateTime: typing.Union[QDateTime, datetime.datetime],
        nameType: "QTimeZone.NameType" = ...,
        locale: QLocale = ...,
    ) -> str:
        """
        https://doc.qt.io/qt-6/qtimezone.html#displayName

        **QString QTimeZone::displayName(const QDateTime & atDateTime ,
        QTimeZone::NameType nameType = QTimeZone::DefaultName, const QLocale &
        locale = QLocale()) const**

        Returns the localized time zone display name at the given **atDateTime**
        for the given **nameType** in the given **locale**. The **nameType** and
        **locale** requested may not be supported on all platforms, in which
        case the best available option will be returned.

        If the **locale** is not provided then the application default locale
        will be used.

        The display name may change depending on DST or historical events.

        **See also** **abbreviation** ().
        """
        ...

    @typing.overload
    def displayName(
        self,
        timeType: "QTimeZone.TimeType",
        nameType: "QTimeZone.NameType" = ...,
        locale: QLocale = ...,
    ) -> str:
        """
        https://doc.qt.io/qt-6/qtimezone.html#displayName-1

        **QString QTimeZone::displayName(QTimeZone::TimeType timeType ,
        QTimeZone::NameType nameType = QTimeZone::DefaultName, const QLocale &
        locale = QLocale()) const**

        Returns the localized time zone display name for the given **timeType**
        and **nameType** in the given **locale**. The **nameType** and
        **locale** requested may not be supported on all platforms, in which
        case the best available option will be returned.

        If the **locale** is not provided then the application default locale
        will be used.

        Where the time zone display names have changed over time then the most
        recent names will be used.

        **See also** **abbreviation** ().
        """
        ...

    def comment(self) -> str:
        """
        https://doc.qt.io/qt-6/qtimezone.html#comment

        **QString QTimeZone::comment() const**

        Returns any comment for the time zone.

        A comment may be provided by the host platform to assist users in
        choosing the correct time zone. Depending on the platform this may not
        be localized.
        """
        ...

    def territory(self) -> QLocale.Country:
        """
        https://doc.qt.io/qt-6/qtimezone.html#territory

        **[since 6.2] QLocale::Territory QTimeZone::territory() const**

        Returns the territory for the time zone.

        This function was introduced in Qt 6.2.
        """
        ...

    def country(self) -> QLocale.Country:
        ...

    def id(self) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qtimezone.html#id

        **QByteArray QTimeZone::id() const**

        Returns the IANA ID for the time zone.

        IANA IDs are used on all platforms. On Windows these are translated from
        the Windows ID into the closest IANA ID for the time zone and territory.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtimezone.html#isValid

        **bool QTimeZone::isValid() const**

        Returns `true` if this time zone is valid.
        """
        ...

    def swap(self, other: "QTimeZone") -> None:
        """
        https://doc.qt.io/qt-6/qtimezone.html#swap

        **void QTimeZone::swap(QTimeZone & other )**

        Swaps this time zone instance with **other**. This function is very fast
        and never fails.
        """
        ...
